@@ -1,11 +1,42 @@
 import logging
 import platform
 
+import requests
 from flexmock import flexmock
 
 from borgmatic.hooks.monitoring import loki as module
 
 
+def test_loki_log_handler_raw_with_send_logs_posts_to_server_after_buffer_full():
+    handler = module.Loki_log_handler(flexmock(), send_logs=True, dry_run=False)
+    flexmock(module.requests).should_receive('post').and_return(
+        flexmock(raise_for_status=lambda: ''),
+    ).once()
+
+    for num in range(int(module.MAX_BUFFER_LINES * 1.5)):
+        handler.raw(num)
+
+
+def test_loki_log_handler_raw_without_send_logs_posts_to_server_without_buffering():
+    handler = module.Loki_log_handler(flexmock(), send_logs=False, dry_run=False)
+    flexmock(module.requests).should_receive('post').and_return(
+        flexmock(raise_for_status=lambda: ''),
+    ).times(3)
+
+    for num in range(3):
+        handler.raw(num)
+
+
+def test_loki_log_handler_raw_post_failure_does_not_raise():
+    handler = module.Loki_log_handler(flexmock(), send_logs=True, dry_run=False)
+    flexmock(module.requests).should_receive('post').and_return(
+        flexmock(raise_for_status=lambda: (_ for _ in ()).throw(requests.RequestException())),
+    ).once()
+
+    for num in range(int(module.MAX_BUFFER_LINES * 1.5)):
+        handler.raw(num)
+
+
 def test_initialize_monitor_replaces_labels():
     '''
     Assert that label placeholders get replaced.
