@@ -618,8 +618,11 @@ def test_collect_spot_check_source_paths_parses_borg_output_and_includes_bootstr
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.borgmatic.execute).should_receive(
         'execute_command_and_capture_output',
-    ).and_return(
-        'warning: stuff\n- /etc/path\n+ /etc/other\n? /nope',
+    ).and_yield(
+        'warning: stuff',
+        '- /etc/path',
+        '+ /etc/other',
+        '? /nope',
     )
     flexmock(module.os.path).should_receive('isfile').and_return(True)
 
@@ -651,7 +654,7 @@ def test_collect_spot_check_source_paths_omits_progress_from_create_dry_run_comm
     flexmock(module.borgmatic.borg.create).should_receive('make_base_create_command').with_args(
         dry_run=True,
         repository_path='repo',
-        config={'working_directory': '/', 'list_details': True},
+        config={'working_directory': '/', 'progress': False, 'list_details': True},
         patterns=[Pattern('foo'), Pattern('bar')],
         local_borg_version=object,
         global_arguments=object,
@@ -666,8 +669,11 @@ def test_collect_spot_check_source_paths_omits_progress_from_create_dry_run_comm
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.borgmatic.execute).should_receive(
         'execute_command_and_capture_output',
-    ).and_return(
-        'warning: stuff\n- /etc/path\n+ /etc/other\n? /nope',
+    ).and_yield(
+        'warning: stuff',
+        '- /etc/path',
+        '+ /etc/other',
+        '? /nope',
     )
     flexmock(module.os.path).should_receive('isfile').and_return(True)
 
@@ -714,8 +720,11 @@ def test_collect_spot_check_source_paths_passes_through_stream_processes_false()
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.borgmatic.execute).should_receive(
         'execute_command_and_capture_output',
-    ).and_return(
-        'warning: stuff\n- /etc/path\n+ /etc/other\n? /nope',
+    ).and_yield(
+        'warning: stuff',
+        '- /etc/path',
+        '+ /etc/other',
+        '? /nope',
     )
     flexmock(module.os.path).should_receive('isfile').and_return(True)
 
@@ -762,8 +771,11 @@ def test_collect_spot_check_source_paths_without_working_directory_parses_borg_o
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.borgmatic.execute).should_receive(
         'execute_command_and_capture_output',
-    ).and_return(
-        'warning: stuff\n- /etc/path\n+ /etc/other\n? /nope',
+    ).and_yield(
+        'warning: stuff',
+        '- /etc/path',
+        '+ /etc/other',
+        '? /nope',
     )
     flexmock(module.os.path).should_receive('isfile').and_return(True)
 
@@ -810,8 +822,11 @@ def test_collect_spot_check_source_paths_skips_directories():
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.borgmatic.execute).should_receive(
         'execute_command_and_capture_output',
-    ).and_return(
-        'warning: stuff\n- /etc/path\n+ /etc/dir\n? /nope',
+    ).and_yield(
+        'warning: stuff',
+        '- /etc/path',
+        '+ /etc/dir',
+        '? /nope',
     )
     flexmock(module.os.path).should_receive('isfile').with_args('/etc/path').and_return(False)
     flexmock(module.os.path).should_receive('isfile').with_args('/etc/dir').and_return(False)
@@ -835,13 +850,11 @@ def test_collect_spot_check_archive_paths_excludes_directories_and_pipes():
     flexmock(module.borgmatic.config.paths).should_receive(
         'get_borgmatic_source_directory',
     ).and_return('/home/user/.borgmatic')
-    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_return(
-        (
-            'f etc/path',
-            'p var/pipe',
-            'f etc/other',
-            'd etc/dir',
-        ),
+    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_yield(
+        {'type': 'f', 'path': 'etc/path'},
+        {'type': 'p', 'path': 'var/pipe'},
+        {'type': 'f', 'path': 'etc/other'},
+        {'type': 'd', 'path': 'etc/dir'},
     )
 
     assert module.collect_spot_check_archive_paths(
@@ -860,11 +873,9 @@ def test_collect_spot_check_archive_paths_excludes_file_in_borgmatic_runtime_dir
     flexmock(module.borgmatic.config.paths).should_receive(
         'get_borgmatic_source_directory',
     ).and_return('/root/.borgmatic')
-    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_return(
-        (
-            'f etc/path',
-            'f borgmatic/some/thing',
-        ),
+    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_yield(
+        {'type': 'f', 'path': 'etc/path'},
+        {'type': 'f', 'path': 'borgmatic/some/thing'},
     )
 
     assert module.collect_spot_check_archive_paths(
@@ -883,11 +894,9 @@ def test_collect_spot_check_archive_paths_excludes_file_in_borgmatic_source_dire
     flexmock(module.borgmatic.config.paths).should_receive(
         'get_borgmatic_source_directory',
     ).and_return('/root/.borgmatic')
-    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_return(
-        (
-            'f etc/path',
-            'f root/.borgmatic/some/thing',
-        ),
+    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_yield(
+        {'type': 'f', 'path': 'etc/path'},
+        {'type': 'f', 'path': 'root/.borgmatic/some/thing'},
     )
 
     assert module.collect_spot_check_archive_paths(
@@ -906,11 +915,9 @@ def test_collect_spot_check_archive_paths_excludes_file_in_borgmatic_runtime_dir
     flexmock(module.borgmatic.config.paths).should_receive(
         'get_borgmatic_source_directory',
     ).and_return('/root.borgmatic')
-    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_return(
-        (
-            'f etc/path',
-            'f run/user/0/borgmatic/some/thing',
-        ),
+    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_yield(
+        {'type': 'f', 'path': 'etc/path'},
+        {'type': 'f', 'path': 'run/user/0/borgmatic/some/thing'},
     )
 
     assert module.collect_spot_check_archive_paths(
@@ -941,7 +948,7 @@ def test_collect_spot_check_source_paths_uses_working_directory():
     flexmock(module.borgmatic.borg.create).should_receive('make_base_create_command').with_args(
         dry_run=True,
         repository_path='repo',
-        config={'working_directory': '/working/dir', 'list_details': True},
+        config={'working_directory': '/working/dir', 'progress': False, 'list_details': True},
         patterns=[Pattern('foo'), Pattern('bar')],
         local_borg_version=object,
         global_arguments=object,
@@ -958,8 +965,11 @@ def test_collect_spot_check_source_paths_uses_working_directory():
     )
     flexmock(module.borgmatic.execute).should_receive(
         'execute_command_and_capture_output',
-    ).and_return(
-        'warning: stuff\n- foo\n+ bar\n? /nope',
+    ).and_yield(
+        'warning: stuff',
+        '- foo',
+        '+ bar',
+        '? /nope',
     )
     flexmock(module.os.path).should_receive('isfile').with_args('/working/dir/foo').and_return(True)
     flexmock(module.os.path).should_receive('isfile').with_args('/working/dir/bar').and_return(True)
@@ -987,11 +997,99 @@ def test_compare_spot_check_hashes_returns_paths_having_failing_hashes():
     flexmock(module.os.path).should_receive('islink').and_return(False)
     flexmock(module.borgmatic.execute).should_receive(
         'execute_command_and_capture_output',
-    ).with_args(('xxh64sum', '/foo', '/bar'), working_directory=None).and_return(
-        'hash1  /foo\nhash2  /bar',
+    ).with_args(('xxh64sum', '/foo', '/bar'), working_directory=None).and_yield(
+        'hash1  /foo',
+        'hash2  /bar',
     )
-    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_return(
-        ['hash1 foo', 'nothash2 bar'],
+    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_yield(
+        {'xxh64': 'hash1', 'path': 'foo'},
+        {'xxh64': 'nothash2', 'path': 'bar'},
+    )
+
+    assert module.compare_spot_check_hashes(
+        repository={'path': 'repo'},
+        archive='archive',
+        config={
+            'checks': [
+                {
+                    'name': 'archives',
+                    'frequency': '2 weeks',
+                },
+                {
+                    'name': 'spot',
+                    'data_sample_percentage': 50,
+                },
+            ],
+        },
+        local_borg_version=flexmock(),
+        global_arguments=flexmock(),
+        local_path=flexmock(),
+        remote_path=flexmock(),
+        source_paths=('/foo', '/bar', '/baz', '/quux'),
+    ) == ('/bar',)
+
+
+def test_compare_spot_check_hashes_handles_weird_backslashed_hashes_from_xxh64sum():
+    flexmock(module.random).should_receive('SystemRandom').and_return(
+        flexmock(sample=lambda population, count: population[:count]),
+    )
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(
+        None,
+    )
+    flexmock(module.os.path).should_receive('exists').and_return(True)
+    flexmock(module.os.path).should_receive('islink').and_return(False)
+    flexmock(module.borgmatic.execute).should_receive(
+        'execute_command_and_capture_output',
+    ).with_args(('xxh64sum', '/foo', '/bar'), working_directory=None).and_yield(
+        '\\hash1  /foo',
+        '\\hash2  /bar',
+    )
+    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_yield(
+        {'xxh64': 'hash1', 'path': 'foo'},
+        {'xxh64': 'nothash2', 'path': 'bar'},
+    )
+
+    assert module.compare_spot_check_hashes(
+        repository={'path': 'repo'},
+        archive='archive',
+        config={
+            'checks': [
+                {
+                    'name': 'archives',
+                    'frequency': '2 weeks',
+                },
+                {
+                    'name': 'spot',
+                    'data_sample_percentage': 50,
+                },
+            ],
+        },
+        local_borg_version=flexmock(),
+        global_arguments=flexmock(),
+        local_path=flexmock(),
+        remote_path=flexmock(),
+        source_paths=('/foo', '/bar', '/baz', '/quux'),
+    ) == ('/bar',)
+
+
+def test_compare_spot_check_hashes_handles_incorrect_path_names_from_xxh64sum():
+    flexmock(module.random).should_receive('SystemRandom').and_return(
+        flexmock(sample=lambda population, count: population[:count]),
+    )
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(
+        None,
+    )
+    flexmock(module.os.path).should_receive('exists').and_return(True)
+    flexmock(module.os.path).should_receive('islink').and_return(False)
+    flexmock(module.borgmatic.execute).should_receive(
+        'execute_command_and_capture_output',
+    ).with_args(('xxh64sum', '/foo', '/bar'), working_directory=None).and_yield(
+        'hash1  /foo/wrong/path',
+        'hash2  /bar/wrong/path',
+    )
+    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_yield(
+        {'xxh64': 'hash1', 'path': 'foo'},
+        {'xxh64': 'nothash2', 'path': 'bar'},
     )
 
     assert module.compare_spot_check_hashes(
@@ -1028,11 +1126,13 @@ def test_compare_spot_check_hashes_returns_relative_paths_having_failing_hashes(
     flexmock(module.os.path).should_receive('islink').and_return(False)
     flexmock(module.borgmatic.execute).should_receive(
         'execute_command_and_capture_output',
-    ).with_args(('xxh64sum', 'foo', 'bar'), working_directory=None).and_return(
-        'hash1  foo\nhash2  bar',
+    ).with_args(('xxh64sum', 'foo', 'bar'), working_directory=None).and_yield(
+        'hash1  foo',
+        'hash2  bar',
     )
-    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_return(
-        ['hash1 foo', 'nothash2 bar'],
+    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_yield(
+        {'xxh64': 'hash1', 'path': 'foo'},
+        {'xxh64': 'nothash2', 'path': 'bar'},
     )
 
     assert module.compare_spot_check_hashes(
@@ -1069,11 +1169,13 @@ def test_compare_spot_check_hashes_handles_data_sample_percentage_above_100():
     flexmock(module.os.path).should_receive('islink').and_return(False)
     flexmock(module.borgmatic.execute).should_receive(
         'execute_command_and_capture_output',
-    ).with_args(('xxh64sum', '/foo', '/bar'), working_directory=None).and_return(
-        'hash1  /foo\nhash2  /bar',
+    ).with_args(('xxh64sum', '/foo', '/bar'), working_directory=None).and_yield(
+        'hash1  /foo',
+        'hash2  /bar',
     )
-    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_return(
-        ['nothash1 foo', 'nothash2 bar'],
+    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_yield(
+        {'xxh64': 'nothash1', 'path': 'foo'},
+        {'xxh64': 'nothash2', 'path': 'bar'},
     )
 
     assert module.compare_spot_check_hashes(
@@ -1113,9 +1215,10 @@ def test_compare_spot_check_hashes_uses_xxh64sum_command_option():
     ).with_args(
         ('/usr/local/bin/xxhsum', '-H64', '/foo', '/bar'),
         working_directory=None,
-    ).and_return('hash1  /foo\nhash2  /bar')
-    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_return(
-        ['hash1 foo', 'nothash2 bar'],
+    ).and_yield('hash1  /foo', 'hash2  /bar')
+    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_yield(
+        {'xxh64': 'hash1', 'path': 'foo'},
+        {'xxh64': 'nothash2', 'path': 'bar'},
     )
 
     assert module.compare_spot_check_hashes(
@@ -1149,11 +1252,12 @@ def test_compare_spot_check_hashes_considers_path_missing_from_archive_as_not_ma
     flexmock(module.os.path).should_receive('islink').and_return(False)
     flexmock(module.borgmatic.execute).should_receive(
         'execute_command_and_capture_output',
-    ).with_args(('xxh64sum', '/foo', '/bar'), working_directory=None).and_return(
-        'hash1  /foo\nhash2  /bar',
+    ).with_args(('xxh64sum', '/foo', '/bar'), working_directory=None).and_yield(
+        'hash1  /foo',
+        'hash2  /bar',
     )
-    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_return(
-        ['hash1 foo'],
+    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_yield(
+        {'xxh64': 'hash1', 'path': 'foo'}
     )
 
     assert module.compare_spot_check_hashes(
@@ -1187,9 +1291,10 @@ def test_compare_spot_check_hashes_considers_symlink_path_as_not_matching():
     flexmock(module.os.path).should_receive('islink').with_args('/bar').and_return(True)
     flexmock(module.borgmatic.execute).should_receive(
         'execute_command_and_capture_output',
-    ).with_args(('xxh64sum', '/foo'), working_directory=None).and_return('hash1  /foo')
-    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_return(
-        ['hash1 foo', 'hash2 bar'],
+    ).with_args(('xxh64sum', '/foo'), working_directory=None).and_yield('hash1  /foo')
+    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_yield(
+        {'xxh64': 'hash1', 'path': 'foo'},
+        {'xxh64': 'hash2', 'path': 'bar'},
     )
 
     assert module.compare_spot_check_hashes(
@@ -1223,9 +1328,10 @@ def test_compare_spot_check_hashes_considers_non_existent_path_as_not_matching()
     flexmock(module.os.path).should_receive('islink').and_return(False)
     flexmock(module.borgmatic.execute).should_receive(
         'execute_command_and_capture_output',
-    ).with_args(('xxh64sum', '/foo'), working_directory=None).and_return('hash1  /foo')
-    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_return(
-        ['hash1 foo', 'hash2 bar'],
+    ).with_args(('xxh64sum', '/foo'), working_directory=None).and_yield('hash1  /foo')
+    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_yield(
+        {'xxh64': 'hash1', 'path': 'foo'},
+        {'xxh64': 'hash2', 'path': 'bar'},
     )
 
     assert module.compare_spot_check_hashes(
@@ -1259,17 +1365,23 @@ def test_compare_spot_check_hashes_with_too_many_paths_feeds_them_to_commands_in
     flexmock(module.os.path).should_receive('islink').and_return(False)
     flexmock(module.borgmatic.execute).should_receive(
         'execute_command_and_capture_output',
-    ).with_args(('xxh64sum', '/foo', '/bar'), working_directory=None).and_return(
-        'hash1  /foo\nhash2  /bar',
+    ).with_args(('xxh64sum', '/foo', '/bar'), working_directory=None).and_yield(
+        'hash1  /foo',
+        'hash2  /bar',
     )
     flexmock(module.borgmatic.execute).should_receive(
         'execute_command_and_capture_output',
-    ).with_args(('xxh64sum', '/baz', '/quux'), working_directory=None).and_return(
-        'hash3  /baz\nhash4  /quux',
+    ).with_args(('xxh64sum', '/baz', '/quux'), working_directory=None).and_yield(
+        'hash3  /baz',
+        'hash4  /quux',
+    )
+    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_yield(
+        {'xxh64': 'hash1', 'path': 'foo'},
+        {'xxh64': 'hash2', 'path': 'bar'},
+    ).and_yield(
+        {'xxh64': 'hash3', 'path': 'baz'},
+        {'xxh64': 'nothash4', 'path': 'quux'},
     )
-    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_return(
-        ['hash1 foo', 'hash2 bar'],
-    ).and_return(['hash3 baz', 'nothash4 quux'])
 
     assert module.compare_spot_check_hashes(
         repository={'path': 'repo'},
@@ -1306,11 +1418,13 @@ def test_compare_spot_check_hashes_uses_working_directory_to_access_source_paths
     flexmock(module.os.path).should_receive('islink').and_return(False)
     flexmock(module.borgmatic.execute).should_receive(
         'execute_command_and_capture_output',
-    ).with_args(('xxh64sum', 'foo', 'bar'), working_directory='/working/dir').and_return(
-        'hash1  foo\nhash2  bar',
+    ).with_args(('xxh64sum', 'foo', 'bar'), working_directory='/working/dir').and_yield(
+        'hash1  foo',
+        'hash2  bar',
     )
-    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_return(
-        ['hash1 foo', 'nothash2 bar'],
+    flexmock(module.borgmatic.borg.list).should_receive('capture_archive_listing').and_yield(
+        {'xxh64': 'hash1', 'path': 'foo'},
+        {'xxh64': 'nothash2', 'path': 'bar'},
     )
 
     assert module.compare_spot_check_hashes(
@@ -1530,7 +1644,6 @@ def test_spot_check_without_any_source_paths_errors():
 
 def test_run_check_checks_archives_for_configured_repository():
     flexmock(module.logger).answer = lambda message: None
-    flexmock(module.borgmatic.config.validate).should_receive('repositories_match').never()
     flexmock(module.borgmatic.borg.check).should_receive('get_repository_id').and_return(flexmock())
     flexmock(module).should_receive('upgrade_check_times')
     flexmock(module).should_receive('parse_checks')
@@ -1566,7 +1679,6 @@ def test_run_check_checks_archives_for_configured_repository():
 
 def test_run_check_runs_configured_extract_check():
     flexmock(module.logger).answer = lambda message: None
-    flexmock(module.borgmatic.config.validate).should_receive('repositories_match').never()
     flexmock(module.borgmatic.borg.check).should_receive('get_repository_id').and_return(flexmock())
     flexmock(module).should_receive('upgrade_check_times')
     flexmock(module).should_receive('parse_checks')
@@ -1600,7 +1712,6 @@ def test_run_check_runs_configured_extract_check():
 
 def test_run_check_runs_configured_spot_check():
     flexmock(module.logger).answer = lambda message: None
-    flexmock(module.borgmatic.config.validate).should_receive('repositories_match').never()
     flexmock(module.borgmatic.borg.check).should_receive('get_repository_id').and_return(flexmock())
     flexmock(module).should_receive('upgrade_check_times')
     flexmock(module).should_receive('parse_checks')
@@ -1637,7 +1748,6 @@ def test_run_check_runs_configured_spot_check():
 
 def test_run_check_without_checks_runs_nothing_except_hooks():
     flexmock(module.logger).answer = lambda message: None
-    flexmock(module.borgmatic.config.validate).should_receive('repositories_match').never()
     flexmock(module.borgmatic.borg.check).should_receive('get_repository_id').and_return(flexmock())
     flexmock(module).should_receive('upgrade_check_times')
     flexmock(module).should_receive('parse_checks')
@@ -1667,68 +1777,3 @@ def test_run_check_without_checks_runs_nothing_except_hooks():
         local_path=None,
         remote_path=None,
     )
-
-
-def test_run_check_checks_archives_in_selected_repository():
-    flexmock(module.logger).answer = lambda message: None
-    flexmock(module.borgmatic.config.validate).should_receive(
-        'repositories_match',
-    ).once().and_return(True)
-    flexmock(module.borgmatic.borg.check).should_receive('get_repository_id').and_return(flexmock())
-    flexmock(module).should_receive('upgrade_check_times')
-    flexmock(module).should_receive('parse_checks')
-    flexmock(module.borgmatic.borg.check).should_receive('make_archive_filter_flags').and_return(())
-    flexmock(module).should_receive('make_archives_check_id').and_return(None)
-    flexmock(module).should_receive('filter_checks_on_frequency').and_return(
-        {'repository', 'archives'},
-    )
-    flexmock(module.borgmatic.borg.check).should_receive('check_archives').once()
-    flexmock(module).should_receive('make_check_time_path')
-    flexmock(module).should_receive('write_check_time')
-    flexmock(module.borgmatic.borg.extract).should_receive('extract_last_archive_dry_run').never()
-    check_arguments = flexmock(
-        repository=flexmock(),
-        progress=flexmock(),
-        repair=flexmock(),
-        only_checks=flexmock(),
-        force=flexmock(),
-    )
-    global_arguments = flexmock(monitoring_verbosity=1, dry_run=False)
-
-    module.run_check(
-        config_filename='test.yaml',
-        repository={'path': 'repo'},
-        config={'repositories': ['repo']},
-        local_borg_version=None,
-        check_arguments=check_arguments,
-        global_arguments=global_arguments,
-        local_path=None,
-        remote_path=None,
-    )
-
-
-def test_run_check_bails_if_repository_does_not_match():
-    flexmock(module.logger).answer = lambda message: None
-    flexmock(module.borgmatic.config.validate).should_receive(
-        'repositories_match',
-    ).once().and_return(False)
-    flexmock(module.borgmatic.borg.check).should_receive('check_archives').never()
-    check_arguments = flexmock(
-        repository=flexmock(),
-        progress=flexmock(),
-        repair=flexmock(),
-        only_checks=flexmock(),
-        force=flexmock(),
-    )
-    global_arguments = flexmock(monitoring_verbosity=1, dry_run=False)
-
-    module.run_check(
-        config_filename='test.yaml',
-        repository={'path': 'repo'},
-        config={'repositories': ['repo']},
-        local_borg_version=None,
-        check_arguments=check_arguments,
-        global_arguments=global_arguments,
-        local_path=None,
-        remote_path=None,
-    )
