@@ -67,25 +67,36 @@ def test_validate_planned_backup_paths_parses_borg_dry_run_file_list():
         lambda arguments, flag: arguments,
     )
     flexmock(module.environment).should_receive('make_environment').and_return(None)
-    flexmock(module).should_receive('execute_command_and_capture_output').and_return(
-        'Processing files ...\n- /foo\n+ /bar\n- /baz',
+    flexmock(module).should_receive('execute_command_and_capture_output').and_yield(
+        'Processing files ...',
+        '- /foo',
+        '+ /bar',
+        '- /baz',
     )
     flexmock(module.os.path).should_receive('exists').and_return(False)
-    flexmock(module).should_receive('any_parent_directories').and_return(False)
+    flexmock(module).should_receive('any_parent_directories').replace_with(
+        lambda path, candidates: any(path.startswith(parent) for parent in candidates)
+    )
+    flexmock(module).should_receive('special_file').with_args('/foo', None).and_return(False)
+    flexmock(module).should_receive('special_file').with_args('/bar', None).and_return(False)
+    flexmock(module).should_receive('special_file').with_args('/baz', None).and_return(False)
 
-    assert module.validate_planned_backup_paths(
-        dry_run=False,
-        create_command=('borg', 'create'),
-        config={},
-        patterns=(
-            module.borgmatic.borg.pattern.Pattern('/foo'),
-            module.borgmatic.borg.pattern.Pattern('/bar'),
-            module.borgmatic.borg.pattern.Pattern('/baz'),
-        ),
-        local_path=None,
-        working_directory=None,
-        borgmatic_runtime_directory='/run/borgmatic',
-    ) == ('/foo', '/bar', '/baz')
+    assert (
+        module.validate_planned_backup_paths(
+            dry_run=False,
+            create_command=('borg', 'create'),
+            config={},
+            patterns=(
+                module.borgmatic.borg.pattern.Pattern('/foo'),
+                module.borgmatic.borg.pattern.Pattern('/bar'),
+                module.borgmatic.borg.pattern.Pattern('/baz'),
+            ),
+            local_path=None,
+            working_directory=None,
+            borgmatic_runtime_directory='/run/borgmatic',
+        )
+        == ()
+    )
 
 
 def test_validate_planned_backup_paths_skips_borgmatic_runtime_directory():
@@ -96,48 +107,20 @@ def test_validate_planned_backup_paths_skips_borgmatic_runtime_directory():
         lambda arguments, flag: arguments,
     )
     flexmock(module.environment).should_receive('make_environment').and_return(None)
-    flexmock(module).should_receive('execute_command_and_capture_output').and_return(
-        '+ /foo\n- /run/borgmatic/bar\n- /baz',
+    flexmock(module).should_receive('execute_command_and_capture_output').and_yield(
+        '+ /foo',
+        '- /run/borgmatic/bar',
+        '- /baz',
     )
     flexmock(module.os.path).should_receive('exists').and_return(True)
     flexmock(module).should_receive('any_parent_directories').replace_with(
         lambda path, candidates: any(path.startswith(parent) for parent in candidates)
     )
+    flexmock(module).should_receive('special_file').with_args('/foo', None).and_return(False)
+    flexmock(module).should_receive('special_file').with_args('/run/borgmatic/bar', None).never()
+    flexmock(module).should_receive('special_file').with_args('/baz', None).and_return(False)
 
-    assert module.validate_planned_backup_paths(
-        dry_run=False,
-        create_command=('borg', 'create'),
-        config={},
-        patterns=(
-            module.borgmatic.borg.pattern.Pattern('/foo'),
-            module.borgmatic.borg.pattern.Pattern(
-                '/run/borgmatic/bar', module.borgmatic.borg.pattern.Pattern_type.ROOT
-            ),
-            module.borgmatic.borg.pattern.Pattern('/baz'),
-        ),
-        local_path=None,
-        working_directory=None,
-        borgmatic_runtime_directory='/run/borgmatic',
-    ) == ('/foo', '/baz')
-
-
-def test_validate_planned_backup_paths_with_borgmatic_runtime_directory_missing_from_paths_output_errors():
-    flexmock(module.flags).should_receive('omit_flag').replace_with(
-        lambda arguments, flag: arguments,
-    )
-    flexmock(module.flags).should_receive('omit_flag_and_value').replace_with(
-        lambda arguments, flag: arguments,
-    )
-    flexmock(module.environment).should_receive('make_environment').and_return(None)
-    flexmock(module).should_receive('execute_command_and_capture_output').and_return(
-        '+ /foo\n- /bar\n- /baz',
-    )
-    flexmock(module.os.path).should_receive('exists').and_return(True)
-    flexmock(module).should_receive('any_parent_directories').replace_with(
-        lambda path, candidates: any(path.startswith(parent) for parent in candidates)
-    )
-
-    with pytest.raises(ValueError):
+    assert (
         module.validate_planned_backup_paths(
             dry_run=False,
             create_command=('borg', 'create'),
@@ -153,9 +136,53 @@ def test_validate_planned_backup_paths_with_borgmatic_runtime_directory_missing_
             working_directory=None,
             borgmatic_runtime_directory='/run/borgmatic',
         )
+        == ()
+    )
 
 
-def test_validate_planned_backup_paths_with_borgmatic_runtime_directory_partially_excluded_from_paths_output_errors():
+def test_validate_planned_backup_paths_with_borgmatic_runtime_directory_missing_from_paths_output_warns():
+    flexmock(module.flags).should_receive('omit_flag').replace_with(
+        lambda arguments, flag: arguments,
+    )
+    flexmock(module.flags).should_receive('omit_flag_and_value').replace_with(
+        lambda arguments, flag: arguments,
+    )
+    flexmock(module.environment).should_receive('make_environment').and_return(None)
+    flexmock(module).should_receive('execute_command_and_capture_output').and_yield(
+        '+ /foo',
+        '- /bar',
+        '- /baz',
+    )
+    flexmock(module.os.path).should_receive('exists').and_return(True)
+    flexmock(module).should_receive('any_parent_directories').replace_with(
+        lambda path, candidates: any(path.startswith(parent) for parent in candidates)
+    )
+    flexmock(module).should_receive('special_file').with_args('/foo', None).and_return(False)
+    flexmock(module).should_receive('special_file').with_args('/bar', None).and_return(False)
+    flexmock(module).should_receive('special_file').with_args('/baz', None).and_return(False)
+    flexmock(module.logger).should_receive('warning').once()
+
+    assert (
+        module.validate_planned_backup_paths(
+            dry_run=False,
+            create_command=('borg', 'create'),
+            config={},
+            patterns=(
+                module.borgmatic.borg.pattern.Pattern('/foo'),
+                module.borgmatic.borg.pattern.Pattern(
+                    '/run/borgmatic/bar', module.borgmatic.borg.pattern.Pattern_type.ROOT
+                ),
+                module.borgmatic.borg.pattern.Pattern('/baz'),
+            ),
+            local_path=None,
+            working_directory=None,
+            borgmatic_runtime_directory='/run/borgmatic',
+        )
+        == ()
+    )
+
+
+def test_validate_planned_backup_paths_with_borgmatic_runtime_directory_partially_excluded_from_paths_output_does_not_warn():
     flexmock(module.flags).should_receive('omit_flag').replace_with(
         lambda arguments, flag: arguments,
     )
@@ -165,15 +192,22 @@ def test_validate_planned_backup_paths_with_borgmatic_runtime_directory_partiall
     flexmock(module.environment).should_receive('make_environment').and_return(None)
 
     # /run/borgmatic/bar is present, but /run/borgmatic/quux is missing.
-    flexmock(module).should_receive('execute_command_and_capture_output').and_return(
-        '+ /foo\n- /run/borgmatic/bar\n- /baz',
+    flexmock(module).should_receive('execute_command_and_capture_output').and_yield(
+        '+ /foo',
+        '- /run/borgmatic/bar',
+        '- /baz',
     )
     flexmock(module.os.path).should_receive('exists').and_return(True)
     flexmock(module).should_receive('any_parent_directories').replace_with(
         lambda path, candidates: any(path.startswith(parent) for parent in candidates)
     )
+    flexmock(module).should_receive('special_file').with_args('/foo', None).and_return(False)
+    flexmock(module).should_receive('special_file').with_args('/run/borgmatic/bar', None).never()
+    flexmock(module).should_receive('special_file').with_args('/baz', None).and_return(False)
+    flexmock(module).should_receive('special_file').with_args('/run/borgmatic/quux', None).never()
+    flexmock(module.logger).should_receive('warning').never()
 
-    with pytest.raises(ValueError):
+    assert (
         module.validate_planned_backup_paths(
             dry_run=False,
             create_command=('borg', 'create'),
@@ -192,6 +226,53 @@ def test_validate_planned_backup_paths_with_borgmatic_runtime_directory_partiall
             working_directory=None,
             borgmatic_runtime_directory='/run/borgmatic',
         )
+        == ()
+    )
+
+
+def test_validate_planned_backup_paths_with_borgmatic_runtime_directory_with_corresponding_include_and_missing_from_paths_output_does_not_warn():
+    flexmock(module.flags).should_receive('omit_flag').replace_with(
+        lambda arguments, flag: arguments,
+    )
+    flexmock(module.flags).should_receive('omit_flag_and_value').replace_with(
+        lambda arguments, flag: arguments,
+    )
+    flexmock(module.environment).should_receive('make_environment').and_return(None)
+    flexmock(module).should_receive('execute_command_and_capture_output').and_yield(
+        '+ /foo',
+        '- /bar',
+        '- /baz',
+    )
+    flexmock(module.os.path).should_receive('exists').and_return(True)
+    flexmock(module).should_receive('any_parent_directories').replace_with(
+        lambda path, candidates: any(path.startswith(parent) for parent in candidates)
+    )
+    flexmock(module).should_receive('special_file').with_args('/foo', None).and_return(False)
+    flexmock(module).should_receive('special_file').with_args('/bar', None).and_return(False)
+    flexmock(module).should_receive('special_file').with_args('/baz', None).and_return(False)
+    flexmock(module.logger).should_receive('warning').never()
+
+    assert (
+        module.validate_planned_backup_paths(
+            dry_run=False,
+            create_command=('borg', 'create'),
+            config={},
+            patterns=(
+                module.borgmatic.borg.pattern.Pattern('/foo'),
+                module.borgmatic.borg.pattern.Pattern(
+                    '/run/borgmatic/bar', module.borgmatic.borg.pattern.Pattern_type.ROOT
+                ),
+                module.borgmatic.borg.pattern.Pattern(
+                    '/run/borgmatic/bar', module.borgmatic.borg.pattern.Pattern_type.INCLUDE
+                ),
+                module.borgmatic.borg.pattern.Pattern('/baz'),
+            ),
+            local_path=None,
+            working_directory=None,
+            borgmatic_runtime_directory='/run/borgmatic',
+        )
+        == ()
+    )
 
 
 def test_validate_planned_backup_paths_with_borgmatic_runtime_directory_missing_from_patterns_does_not_raise():
@@ -202,26 +283,33 @@ def test_validate_planned_backup_paths_with_borgmatic_runtime_directory_missing_
         lambda arguments, flag: arguments,
     )
     flexmock(module.environment).should_receive('make_environment').and_return(None)
-    flexmock(module).should_receive('execute_command_and_capture_output').and_return(
-        '+ /foo\n- /run/borgmatic/bar\n- /baz',
+    flexmock(module).should_receive('execute_command_and_capture_output').and_yield(
+        '+ /foo',
+        '- /run/borgmatic/bar',
+        '- /baz',
     )
     flexmock(module.os.path).should_receive('exists').and_return(True)
     flexmock(module).should_receive('any_parent_directories').replace_with(
         lambda path, candidates: any(path.startswith(parent) for parent in candidates)
     )
+    flexmock(module).should_receive('special_file').with_args('/foo', None).and_return(False)
+    flexmock(module).should_receive('special_file').with_args('/baz', None).and_return(False)
 
-    assert module.validate_planned_backup_paths(
-        dry_run=False,
-        create_command=('borg', 'create'),
-        config={},
-        patterns=(
-            module.borgmatic.borg.pattern.Pattern('/foo'),
-            module.borgmatic.borg.pattern.Pattern('/baz'),
-        ),
-        local_path=None,
-        working_directory=None,
-        borgmatic_runtime_directory='/run/borgmatic',
-    ) == ('/foo', '/baz')
+    assert (
+        module.validate_planned_backup_paths(
+            dry_run=False,
+            create_command=('borg', 'create'),
+            config={},
+            patterns=(
+                module.borgmatic.borg.pattern.Pattern('/foo'),
+                module.borgmatic.borg.pattern.Pattern('/baz'),
+            ),
+            local_path=None,
+            working_directory=None,
+            borgmatic_runtime_directory='/run/borgmatic',
+        )
+        == ()
+    )
 
 
 def test_validate_planned_backup_paths_with_dry_run_and_borgmatic_runtime_directory_missing_from_paths_output_does_not_raise():
@@ -232,27 +320,37 @@ def test_validate_planned_backup_paths_with_dry_run_and_borgmatic_runtime_direct
         lambda arguments, flag: arguments,
     )
     flexmock(module.environment).should_receive('make_environment').and_return(None)
-    flexmock(module).should_receive('execute_command_and_capture_output').and_return(
-        '+ /foo\n- /run/borgmatic/bar\n- /baz',
+    flexmock(module).should_receive('execute_command_and_capture_output').and_yield(
+        '+ /foo',
+        '- /run/borgmatic/bar',
+        '- /baz',
     )
     flexmock(module.os.path).should_receive('exists').and_return(True)
-    flexmock(module).should_receive('any_parent_directories').and_return(False)
+    flexmock(module).should_receive('any_parent_directories').replace_with(
+        lambda path, candidates: any(path.startswith(parent) for parent in candidates)
+    )
+    flexmock(module).should_receive('special_file').with_args('/foo', None).and_return(False)
+    flexmock(module).should_receive('special_file').with_args('/run/borgmatic/bar', None).never()
+    flexmock(module).should_receive('special_file').with_args('/baz', None).and_return(False)
 
-    assert module.validate_planned_backup_paths(
-        dry_run=True,
-        create_command=('borg', 'create'),
-        config={},
-        patterns=(
-            module.borgmatic.borg.pattern.Pattern('/foo'),
-            module.borgmatic.borg.pattern.Pattern(
-                '/run/borgmatic/bar', module.borgmatic.borg.pattern.Pattern_type.ROOT
+    assert (
+        module.validate_planned_backup_paths(
+            dry_run=True,
+            create_command=('borg', 'create'),
+            config={},
+            patterns=(
+                module.borgmatic.borg.pattern.Pattern('/foo'),
+                module.borgmatic.borg.pattern.Pattern(
+                    '/run/borgmatic/bar', module.borgmatic.borg.pattern.Pattern_type.ROOT
+                ),
+                module.borgmatic.borg.pattern.Pattern('/baz'),
             ),
-            module.borgmatic.borg.pattern.Pattern('/baz'),
-        ),
-        local_path=None,
-        working_directory=None,
-        borgmatic_runtime_directory='/run/borgmatic',
-    ) == ('/foo', '/run/borgmatic/bar', '/baz')
+            local_path=None,
+            working_directory=None,
+            borgmatic_runtime_directory='/run/borgmatic',
+        )
+        == ()
+    )
 
 
 DEFAULT_ARCHIVE_NAME = '{hostname}-{now:%Y-%m-%dT%H:%M:%S.%f}'
@@ -283,7 +381,7 @@ def test_make_base_create_produces_borg_command():
         borgmatic_runtime_directory='/run/borgmatic',
     )
 
-    assert create_flags == ('borg', 'create')
+    assert create_flags == ('borg', 'create', '--log-json')
     assert create_positional_arguments == REPO_ARCHIVE
     assert not pattern_file
 
@@ -320,7 +418,7 @@ def test_make_base_create_command_includes_patterns_file_in_borg_command():
         borgmatic_runtime_directory='/run/borgmatic',
     )
 
-    assert create_flags == ('borg', 'create', *pattern_flags)
+    assert create_flags == ('borg', 'create', *pattern_flags, '--log-json')
     assert create_positional_arguments == (f'repo::{DEFAULT_ARCHIVE_NAME}',)
     assert pattern_file == mock_pattern_file
 
@@ -353,7 +451,7 @@ def test_make_base_create_command_with_store_config_false_omits_config_files():
         borgmatic_runtime_directory='/run/borgmatic',
     )
 
-    assert create_flags == ('borg', 'create')
+    assert create_flags == ('borg', 'create', '--log-json')
     assert create_positional_arguments == REPO_ARCHIVE
     assert not pattern_file
 
@@ -422,7 +520,76 @@ def test_make_base_create_command_includes_configuration_option_as_command_flag(
         borgmatic_runtime_directory='/run/borgmatic',
     )
 
-    assert create_flags == ('borg', 'create', *option_flags)
+    assert create_flags == ('borg', 'create', *option_flags, '--log-json')
+    assert create_positional_arguments == REPO_ARCHIVE
+    assert not pattern_file
+
+
+def test_make_base_create_command_with_progress_omits_log_json_from_borg_command():
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
+    flexmock(module.borgmatic.borg.pattern).should_receive('write_patterns_file').and_return(None)
+    flexmock(module.borgmatic.borg.flags).should_receive('make_list_filter_flags').and_return('FOO')
+    flexmock(module.flags).should_receive('get_default_archive_name_format').and_return(
+        '{hostname}',
+    )
+    flexmock(module.feature).should_receive('available').and_return(True)
+    flexmock(module.borgmatic.borg.flags).should_receive('make_exclude_flags').and_return(())
+    flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
+        (f'repo::{DEFAULT_ARCHIVE_NAME}',),
+    )
+    flexmock(module).should_receive('validate_planned_backup_paths').and_return(())
+
+    (create_flags, create_positional_arguments, pattern_file) = module.make_base_create_command(
+        dry_run=False,
+        repository_path='repo',
+        config={
+            'source_directories': ['foo', 'bar'],
+            'repositories': ['repo'],
+            'exclude_patterns': ['exclude'],
+            'progress': True,
+        },
+        patterns=[Pattern('foo'), Pattern('bar')],
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(),
+        borgmatic_runtime_directory='/run/borgmatic',
+    )
+
+    assert create_flags == ('borg', 'create')
+    assert create_positional_arguments == REPO_ARCHIVE
+    assert not pattern_file
+
+
+def test_make_base_create_command_with_log_json_and_progress_includes_log_json_in_borg_command():
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
+    flexmock(module.borgmatic.borg.pattern).should_receive('write_patterns_file').and_return(None)
+    flexmock(module.borgmatic.borg.flags).should_receive('make_list_filter_flags').and_return('FOO')
+    flexmock(module.flags).should_receive('get_default_archive_name_format').and_return(
+        '{hostname}',
+    )
+    flexmock(module.feature).should_receive('available').and_return(True)
+    flexmock(module.borgmatic.borg.flags).should_receive('make_exclude_flags').and_return(())
+    flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
+        (f'repo::{DEFAULT_ARCHIVE_NAME}',),
+    )
+    flexmock(module).should_receive('validate_planned_backup_paths').and_return(())
+
+    (create_flags, create_positional_arguments, pattern_file) = module.make_base_create_command(
+        dry_run=False,
+        repository_path='repo',
+        config={
+            'source_directories': ['foo', 'bar'],
+            'repositories': ['repo'],
+            'exclude_patterns': ['exclude'],
+            'log_json': True,
+            'progress': True,
+        },
+        patterns=[Pattern('foo'), Pattern('bar')],
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(),
+        borgmatic_runtime_directory='/run/borgmatic',
+    )
+
+    assert create_flags == ('borg', 'create', '--log-json')
     assert create_positional_arguments == REPO_ARCHIVE
     assert not pattern_file
 
@@ -455,7 +622,7 @@ def test_make_base_create_command_includes_dry_run_in_borg_command():
         borgmatic_runtime_directory='/run/borgmatic',
     )
 
-    assert create_flags == ('borg', 'create', '--dry-run')
+    assert create_flags == ('borg', 'create', '--log-json', '--dry-run')
     assert create_positional_arguments == REPO_ARCHIVE
     assert not pattern_file
 
@@ -489,7 +656,7 @@ def test_make_base_create_command_includes_comment_in_borg_command():
         comment='a comment',
     )
 
-    assert create_flags == ('borg', 'create', '--comment', 'a comment')
+    assert create_flags == ('borg', 'create', '--comment', 'a comment', '--log-json')
     assert create_positional_arguments == REPO_ARCHIVE
     assert not pattern_file
 
@@ -522,7 +689,7 @@ def test_make_base_create_command_includes_local_path_in_borg_command():
         local_path='borg1',
     )
 
-    assert create_flags == ('borg1', 'create')
+    assert create_flags == ('borg1', 'create', '--log-json')
     assert create_positional_arguments == REPO_ARCHIVE
     assert not pattern_file
 
@@ -555,40 +722,7 @@ def test_make_base_create_command_includes_remote_path_in_borg_command():
         remote_path='borg1',
     )
 
-    assert create_flags == ('borg', 'create', '--remote-path', 'borg1')
-    assert create_positional_arguments == REPO_ARCHIVE
-    assert not pattern_file
-
-
-def test_make_base_create_command_includes_log_json_in_borg_command():
-    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
-    flexmock(module.borgmatic.borg.pattern).should_receive('write_patterns_file').and_return(None)
-    flexmock(module.borgmatic.borg.flags).should_receive('make_list_filter_flags').and_return('FOO')
-    flexmock(module.flags).should_receive('get_default_archive_name_format').and_return(
-        '{hostname}',
-    )
-    flexmock(module.feature).should_receive('available').and_return(True)
-    flexmock(module.borgmatic.borg.flags).should_receive('make_exclude_flags').and_return(())
-    flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        (f'repo::{DEFAULT_ARCHIVE_NAME}',),
-    )
-    flexmock(module).should_receive('validate_planned_backup_paths').and_return(())
-
-    (create_flags, create_positional_arguments, pattern_file) = module.make_base_create_command(
-        dry_run=False,
-        repository_path='repo',
-        config={
-            'source_directories': ['foo', 'bar'],
-            'repositories': ['repo'],
-            'log_json': True,
-        },
-        patterns=[Pattern('foo'), Pattern('bar')],
-        local_borg_version='1.2.3',
-        global_arguments=flexmock(),
-        borgmatic_runtime_directory='/run/borgmatic',
-    )
-
-    assert create_flags == ('borg', 'create', '--log-json')
+    assert create_flags == ('borg', 'create', '--remote-path', 'borg1', '--log-json')
     assert create_positional_arguments == REPO_ARCHIVE
     assert not pattern_file
 
@@ -621,7 +755,7 @@ def test_make_base_create_command_includes_list_flags_in_borg_command():
         borgmatic_runtime_directory='/run/borgmatic',
     )
 
-    assert create_flags == ('borg', 'create', '--list', '--filter', 'FOO')
+    assert create_flags == ('borg', 'create', '--log-json', '--list', '--filter', 'FOO')
     assert create_positional_arguments == REPO_ARCHIVE
     assert not pattern_file
 
@@ -645,18 +779,7 @@ def test_make_base_create_command_with_stream_processes_ignores_read_special_fal
     )
     flexmock(module.logger).should_receive('warning').twice()
     flexmock(module.environment).should_receive('make_environment')
-    flexmock(module).should_receive('validate_planned_backup_paths').and_return(
-        (
-            '/non/special',
-            '/dev/null',
-        )
-    )
-    flexmock(module).should_receive('special_file').with_args(
-        '/non/special', working_directory=None
-    ).and_return(False)
-    flexmock(module).should_receive('special_file').with_args(
-        '/dev/null', working_directory=None
-    ).and_return(True)
+    flexmock(module).should_receive('validate_planned_backup_paths').and_return(('/dev/null',))
     flexmock(module.borgmatic.borg.pattern).should_receive('write_patterns_file').with_args(
         (
             Pattern(
@@ -686,7 +809,14 @@ def test_make_base_create_command_with_stream_processes_ignores_read_special_fal
         stream_processes=flexmock(),
     )
 
-    assert create_flags == ('borg', 'create', '--patterns-from', 'patterns', '--read-special')
+    assert create_flags == (
+        'borg',
+        'create',
+        '--patterns-from',
+        'patterns',
+        '--read-special',
+        '--log-json',
+    )
     assert create_positional_arguments == REPO_ARCHIVE
     assert pattern_file
 
@@ -708,18 +838,7 @@ def test_make_base_create_command_without_patterns_and_with_stream_processes_ign
     )
     flexmock(module.logger).should_receive('warning').twice()
     flexmock(module.environment).should_receive('make_environment')
-    flexmock(module).should_receive('validate_planned_backup_paths').and_return(
-        (
-            '/non/special',
-            '/dev/null',
-        )
-    )
-    flexmock(module).should_receive('special_file').with_args(
-        '/non/special', working_directory=None
-    ).and_return(False)
-    flexmock(module).should_receive('special_file').with_args(
-        '/dev/null', working_directory=None
-    ).and_return(True)
+    flexmock(module).should_receive('validate_planned_backup_paths').and_return(('/dev/null',))
     flexmock(module.borgmatic.borg.pattern).should_receive('write_patterns_file').with_args(
         (
             Pattern(
@@ -749,7 +868,14 @@ def test_make_base_create_command_without_patterns_and_with_stream_processes_ign
         stream_processes=flexmock(),
     )
 
-    assert create_flags == ('borg', 'create', '--read-special', '--patterns-from', 'patterns')
+    assert create_flags == (
+        'borg',
+        'create',
+        '--read-special',
+        '--log-json',
+        '--patterns-from',
+        'patterns',
+    )
     assert create_positional_arguments == REPO_ARCHIVE
     assert pattern_file
 
@@ -784,7 +910,7 @@ def test_make_base_create_command_with_stream_processes_and_read_special_true_sk
         stream_processes=flexmock(),
     )
 
-    assert create_flags == ('borg', 'create', '--read-special')
+    assert create_flags == ('borg', 'create', '--read-special', '--log-json')
     assert create_positional_arguments == REPO_ARCHIVE
     assert not pattern_file
 
@@ -817,7 +943,7 @@ def test_make_base_create_command_includes_archive_name_format_in_borg_command()
         borgmatic_runtime_directory='/run/borgmatic',
     )
 
-    assert create_flags == ('borg', 'create')
+    assert create_flags == ('borg', 'create', '--log-json')
     assert create_positional_arguments == ('repo::ARCHIVE_NAME',)
     assert not pattern_file
 
@@ -849,7 +975,7 @@ def test_make_base_create_command_includes_default_archive_name_format_in_borg_c
         borgmatic_runtime_directory='/run/borgmatic',
     )
 
-    assert create_flags == ('borg', 'create')
+    assert create_flags == ('borg', 'create', '--log-json')
     assert create_positional_arguments == ('repo::{hostname}',)
     assert not pattern_file
 
@@ -882,7 +1008,7 @@ def test_make_base_create_command_includes_archive_name_format_with_placeholders
         borgmatic_runtime_directory='/run/borgmatic',
     )
 
-    assert create_flags == ('borg', 'create')
+    assert create_flags == ('borg', 'create', '--log-json')
     assert create_positional_arguments == (repository_archive_pattern,)
     assert not pattern_file
 
@@ -915,7 +1041,7 @@ def test_make_base_create_command_includes_repository_and_archive_name_format_wi
         borgmatic_runtime_directory='/run/borgmatic',
     )
 
-    assert create_flags == ('borg', 'create')
+    assert create_flags == ('borg', 'create', '--log-json')
     assert create_positional_arguments == (repository_archive_pattern,)
     assert not pattern_file
 
@@ -944,7 +1070,7 @@ def test_make_base_create_command_includes_archive_suffix_in_borg_command():
         archive_suffix='.checkpoint',
     )
 
-    assert create_flags == ('borg', 'create')
+    assert create_flags == ('borg', 'create', '--log-json')
     assert create_positional_arguments == (f'repo::{DEFAULT_ARCHIVE_NAME}.checkpoint',)
     assert not pattern_file
 
@@ -977,11 +1103,76 @@ def test_make_base_create_command_includes_extra_borg_options_in_borg_command():
         borgmatic_runtime_directory='/run/borgmatic',
     )
 
-    assert create_flags == ('borg', 'create', '--extra', '--options', 'value with space')
+    assert create_flags == (
+        'borg',
+        'create',
+        '--log-json',
+        '--extra',
+        '--options',
+        'value with space',
+    )
     assert create_positional_arguments == REPO_ARCHIVE
     assert not pattern_file
 
 
+def test_make_base_create_command_with_unsafe_skip_path_validation_before_create_skips_validation():
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
+    flexmock(module.borgmatic.borg.pattern).should_receive('write_patterns_file').and_return(None)
+    flexmock(module.borgmatic.borg.flags).should_receive('make_list_filter_flags').and_return('FOO')
+    flexmock(module.flags).should_receive('get_default_archive_name_format').and_return(
+        '{hostname}',
+    )
+    flexmock(module.feature).should_receive('available').and_return(True)
+    flexmock(module.borgmatic.borg.flags).should_receive('make_exclude_flags').and_return(())
+    flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
+        (f'repo::{module.flags.get_default_archive_name_format()}',),
+    )
+    flexmock(module).should_receive('validate_planned_backup_paths').never()
+    flexmock(module.logger).should_receive('warning').once()
+
+    module.make_base_create_command(
+        dry_run=False,
+        repository_path='repo',
+        config={
+            'source_directories': ['foo', 'bar'],
+            'repositories': ['repo'],
+            'unsafe_skip_path_validation_before_create': True,
+        },
+        patterns=[Pattern('foo'), Pattern('bar')],
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(),
+        borgmatic_runtime_directory='/run/borgmatic',
+    )
+
+
+def test_make_base_create_command_without_unsafe_skip_path_validation_before_create_calls_validation():
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
+    flexmock(module.borgmatic.borg.pattern).should_receive('write_patterns_file').and_return(None)
+    flexmock(module.borgmatic.borg.flags).should_receive('make_list_filter_flags').and_return('FOO')
+    flexmock(module.flags).should_receive('get_default_archive_name_format').and_return(
+        '{hostname}',
+    )
+    flexmock(module.feature).should_receive('available').and_return(True)
+    flexmock(module.borgmatic.borg.flags).should_receive('make_exclude_flags').and_return(())
+    flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
+        (f'repo::{module.flags.get_default_archive_name_format()}',),
+    )
+    flexmock(module).should_receive('validate_planned_backup_paths').once().and_return(())
+
+    module.make_base_create_command(
+        dry_run=False,
+        repository_path='repo',
+        config={
+            'source_directories': ['foo', 'bar'],
+            'repositories': ['repo'],
+        },
+        patterns=[Pattern('foo'), Pattern('bar')],
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(),
+        borgmatic_runtime_directory='/run/borgmatic',
+    )
+
+
 def test_make_base_create_command_with_non_existent_directory_and_source_directories_must_exist_raises():
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.borgmatic.borg.pattern).should_receive(
@@ -1119,7 +1310,7 @@ def test_create_archive_with_log_info_and_json_suppresses_most_borg_output():
         environment=None,
         borg_local_path='borg',
         borg_exit_codes=None,
-    )
+    ).and_yield()
     insert_logging_mock(logging.INFO)
 
     module.create_archive(
@@ -1186,7 +1377,7 @@ def test_create_archive_with_log_debug_and_json_suppresses_most_borg_output():
         environment=None,
         borg_local_path='borg',
         borg_exit_codes=None,
-    )
+    ).and_yield()
     insert_logging_mock(logging.DEBUG)
 
     module.create_archive(
@@ -1476,7 +1667,7 @@ def test_create_archive_with_progress_and_stream_processes_calls_borg_with_progr
         borg_exit_codes=None,
         working_directory=None,
         environment=None,
-    )
+    ).and_yield()
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         create_command,
         processes=processes,
@@ -1486,7 +1677,7 @@ def test_create_archive_with_progress_and_stream_processes_calls_borg_with_progr
         borg_exit_codes=None,
         working_directory=None,
         environment=None,
-    )
+    ).and_yield()
 
     module.create_archive(
         dry_run=False,
@@ -1519,7 +1710,7 @@ def test_create_archive_with_json_calls_borg_with_json_flag():
         environment=None,
         borg_local_path='borg',
         borg_exit_codes=None,
-    ).and_return('[]')
+    ).and_yield('[]')
 
     json_output = module.create_archive(
         dry_run=False,
@@ -1553,7 +1744,7 @@ def test_create_archive_with_stats_and_json_calls_borg_without_stats_flag():
         environment=None,
         borg_local_path='borg',
         borg_exit_codes=None,
-    ).and_return('[]')
+    ).and_yield('[]')
 
     json_output = module.create_archive(
         dry_run=False,
@@ -1642,3 +1833,85 @@ def test_create_archive_calls_borg_with_working_directory():
         global_arguments=flexmock(),
         borgmatic_runtime_directory='/borgmatic/run',
     )
+
+
+def test_validate_planned_backup_paths_returns_special_files():
+    flexmock(module.flags).should_receive('omit_flag').replace_with(
+        lambda arguments, flag: arguments,
+    )
+    flexmock(module.flags).should_receive('omit_flag_and_value').replace_with(
+        lambda arguments, flag: arguments,
+    )
+    flexmock(module.environment).should_receive('make_environment').and_return(None)
+    flexmock(module).should_receive('execute_command_and_capture_output').and_yield(
+        '+ /dev/foo',
+        '- /run/borgmatic/bar',
+        '- /dev/baz',
+        '- /quux',
+    )
+    flexmock(module.os.path).should_receive('exists').and_return(True)
+    flexmock(module).should_receive('any_parent_directories').replace_with(
+        lambda path, candidates: any(path.startswith(parent) for parent in candidates)
+    )
+    flexmock(module).should_receive('special_file').with_args('/dev/foo', None).and_return(True)
+    flexmock(module).should_receive('special_file').with_args('/run/borgmatic/bar', None).never()
+    flexmock(module).should_receive('special_file').with_args('/dev/baz', None).and_return(True)
+    flexmock(module).should_receive('special_file').with_args('/quux', None).and_return(False)
+
+    assert module.validate_planned_backup_paths(
+        dry_run=False,
+        create_command=('borg', 'create'),
+        config={},
+        patterns=(
+            module.borgmatic.borg.pattern.Pattern('/dev/foo'),
+            module.borgmatic.borg.pattern.Pattern(
+                '/run/borgmatic/bar', module.borgmatic.borg.pattern.Pattern_type.ROOT
+            ),
+            module.borgmatic.borg.pattern.Pattern('/dev/baz'),
+        ),
+        local_path=None,
+        working_directory=None,
+        borgmatic_runtime_directory='/run/borgmatic',
+        find_special_files=True,
+    ) == ('/dev/foo', '/dev/baz')
+
+
+def test_validate_planned_backup_paths_without_find_special_files_ignores_special_files():
+    flexmock(module.flags).should_receive('omit_flag').replace_with(
+        lambda arguments, flag: arguments,
+    )
+    flexmock(module.flags).should_receive('omit_flag_and_value').replace_with(
+        lambda arguments, flag: arguments,
+    )
+    flexmock(module.environment).should_receive('make_environment').and_return(None)
+    flexmock(module).should_receive('execute_command_and_capture_output').and_yield(
+        '+ /dev/foo',
+        '- /run/borgmatic/bar',
+        '- /dev/baz',
+        '- /quux',
+    )
+    flexmock(module.os.path).should_receive('exists').and_return(True)
+    flexmock(module).should_receive('any_parent_directories').replace_with(
+        lambda path, candidates: any(path.startswith(parent) for parent in candidates)
+    )
+    flexmock(module).should_receive('special_file').never()
+
+    assert (
+        module.validate_planned_backup_paths(
+            dry_run=False,
+            create_command=('borg', 'create'),
+            config={},
+            patterns=(
+                module.borgmatic.borg.pattern.Pattern('/dev/foo'),
+                module.borgmatic.borg.pattern.Pattern(
+                    '/run/borgmatic/bar', module.borgmatic.borg.pattern.Pattern_type.ROOT
+                ),
+                module.borgmatic.borg.pattern.Pattern('/dev/baz'),
+            ),
+            local_path=None,
+            working_directory=None,
+            borgmatic_runtime_directory='/run/borgmatic',
+            find_special_files=False,
+        )
+        == ()
+    )
