@@ -24,7 +24,7 @@ def insert_execute_command_mock(command, working_directory=None, borg_exit_codes
 def test_mount_archive_calls_borg_with_required_flags():
     flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
-    insert_execute_command_mock(('borg', 'mount', 'repo', '/mnt'))
+    insert_execute_command_mock(('borg', 'mount', '--log-json', 'repo', '/mnt'))
 
     mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
     module.mount_archive(
@@ -46,7 +46,7 @@ def test_mount_archive_with_borg_features_calls_borg_with_repository_and_match_a
         ),
     )
     insert_execute_command_mock(
-        ('borg', 'mount', '--repo', 'repo', '--match-archives', 'archive', '/mnt'),
+        ('borg', 'mount', '--log-json', '--repo', 'repo', '--match-archives', 'archive', '/mnt'),
     )
 
     mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
@@ -65,7 +65,7 @@ def test_mount_archive_without_archive_calls_borg_with_repository_flags_only():
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',),
     )
-    insert_execute_command_mock(('borg', 'mount', 'repo::archive', '/mnt'))
+    insert_execute_command_mock(('borg', 'mount', '--log-json', 'repo::archive', '/mnt'))
 
     mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
     module.mount_archive(
@@ -83,7 +83,9 @@ def test_mount_archive_calls_borg_with_path_flags():
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',),
     )
-    insert_execute_command_mock(('borg', 'mount', 'repo::archive', '/mnt', 'path1', 'path2'))
+    insert_execute_command_mock(
+        ('borg', 'mount', '--log-json', 'repo::archive', '/mnt', 'path1', 'path2')
+    )
 
     mount_arguments = flexmock(
         mount_point='/mnt',
@@ -106,7 +108,7 @@ def test_mount_archive_calls_borg_with_local_path():
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',),
     )
-    insert_execute_command_mock(('borg1', 'mount', 'repo::archive', '/mnt'))
+    insert_execute_command_mock(('borg1', 'mount', '--log-json', 'repo::archive', '/mnt'))
 
     mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
     module.mount_archive(
@@ -127,7 +129,7 @@ def test_mount_archive_calls_borg_using_exit_codes():
     )
     borg_exit_codes = flexmock()
     insert_execute_command_mock(
-        ('borg', 'mount', 'repo::archive', '/mnt'),
+        ('borg', 'mount', '--log-json', 'repo::archive', '/mnt'),
         borg_exit_codes=borg_exit_codes,
     )
 
@@ -148,7 +150,7 @@ def test_mount_archive_calls_borg_with_remote_path_flags():
         ('repo::archive',),
     )
     insert_execute_command_mock(
-        ('borg', 'mount', '--remote-path', 'borg1', 'repo::archive', '/mnt'),
+        ('borg', 'mount', '--remote-path', 'borg1', '--log-json', 'repo::archive', '/mnt'),
     )
 
     mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
@@ -168,7 +170,9 @@ def test_mount_archive_calls_borg_with_umask_flags():
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',),
     )
-    insert_execute_command_mock(('borg', 'mount', '--umask', '0770', 'repo::archive', '/mnt'))
+    insert_execute_command_mock(
+        ('borg', 'mount', '--umask', '0770', '--log-json', 'repo::archive', '/mnt')
+    )
 
     mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
     module.mount_archive(
@@ -181,30 +185,14 @@ def test_mount_archive_calls_borg_with_umask_flags():
     )
 
 
-def test_mount_archive_calls_borg_with_log_json_flags():
-    flexmock(module.feature).should_receive('available').and_return(False)
-    flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',),
-    )
-    insert_execute_command_mock(('borg', 'mount', '--log-json', 'repo::archive', '/mnt'))
-
-    mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
-    module.mount_archive(
-        repository_path='repo',
-        archive='archive',
-        mount_arguments=mount_arguments,
-        config={'log_json': True},
-        local_borg_version='1.2.3',
-        global_arguments=flexmock(),
-    )
-
-
 def test_mount_archive_calls_borg_with_lock_wait_flags():
     flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',),
     )
-    insert_execute_command_mock(('borg', 'mount', '--lock-wait', '5', 'repo::archive', '/mnt'))
+    insert_execute_command_mock(
+        ('borg', 'mount', '--log-json', '--lock-wait', '5', 'repo::archive', '/mnt')
+    )
 
     mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
     module.mount_archive(
@@ -223,7 +211,7 @@ def test_mount_archive_calls_borg_with_extra_borg_options():
         ('repo::archive',),
     )
     insert_execute_command_mock(
-        ('borg', 'mount', '--extra', 'value with space', 'repo::archive', '/mnt')
+        ('borg', 'mount', '--log-json', '--extra', 'value with space', 'repo::archive', '/mnt')
     )
 
     mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
@@ -242,7 +230,7 @@ def test_mount_archive_with_log_info_calls_borg_with_info_parameter():
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',),
     )
-    insert_execute_command_mock(('borg', 'mount', '--info', 'repo::archive', '/mnt'))
+    insert_execute_command_mock(('borg', 'mount', '--log-json', '--info', 'repo::archive', '/mnt'))
     insert_logging_mock(logging.INFO)
 
     mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
@@ -261,7 +249,9 @@ def test_mount_archive_with_log_debug_calls_borg_with_debug_flags():
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',),
     )
-    insert_execute_command_mock(('borg', 'mount', '--debug', '--show-rc', 'repo::archive', '/mnt'))
+    insert_execute_command_mock(
+        ('borg', 'mount', '--log-json', '--debug', '--show-rc', 'repo::archive', '/mnt')
+    )
     insert_logging_mock(logging.DEBUG)
 
     mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
@@ -307,7 +297,9 @@ def test_mount_archive_calls_borg_with_options_flags():
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',),
     )
-    insert_execute_command_mock(('borg', 'mount', '-o', 'super_mount', 'repo::archive', '/mnt'))
+    insert_execute_command_mock(
+        ('borg', 'mount', '--log-json', '-o', 'super_mount', 'repo::archive', '/mnt')
+    )
 
     mount_arguments = flexmock(
         mount_point='/mnt',
@@ -349,6 +341,7 @@ def test_mount_archive_with_date_based_matching_calls_borg_with_date_based_flags
         (
             'borg',
             'mount',
+            '--log-json',
             '--newer',
             '1d',
             '--newest',
@@ -392,7 +385,9 @@ def test_mount_archive_with_date_based_matching_calls_borg_with_date_based_flags
 def test_mount_archive_calls_borg_with_working_directory():
     flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
-    insert_execute_command_mock(('borg', 'mount', 'repo', '/mnt'), working_directory='/working/dir')
+    insert_execute_command_mock(
+        ('borg', 'mount', '--log-json', 'repo', '/mnt'), working_directory='/working/dir'
+    )
 
     mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
     module.mount_archive(
