@@ -23,9 +23,10 @@ def test_make_repo_delete_command_with_feature_available_runs_borg_repo_delete()
         global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
+        output_file=None,
     )
 
-    assert command == ('borg', 'repo-delete', 'repo')
+    assert command == ('borg', 'repo-delete', '--log-json', 'repo')
 
 
 def test_make_repo_delete_command_without_feature_available_runs_borg_delete():
@@ -44,9 +45,10 @@ def test_make_repo_delete_command_without_feature_available_runs_borg_delete():
         global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
+        output_file=None,
     )
 
-    assert command == ('borg', 'delete', 'repo')
+    assert command == ('borg', 'delete', '--log-json', 'repo')
 
 
 def test_make_repo_delete_command_includes_log_info():
@@ -66,9 +68,10 @@ def test_make_repo_delete_command_includes_log_info():
         global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
+        output_file=None,
     )
 
-    assert command == ('borg', 'repo-delete', '--info', 'repo')
+    assert command == ('borg', 'repo-delete', '--info', '--log-json', 'repo')
 
 
 def test_make_repo_delete_command_includes_log_debug():
@@ -88,9 +91,10 @@ def test_make_repo_delete_command_includes_log_debug():
         global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
+        output_file=None,
     )
 
-    assert command == ('borg', 'repo-delete', '--debug', '--show-rc', 'repo')
+    assert command == ('borg', 'repo-delete', '--debug', '--show-rc', '--log-json', 'repo')
 
 
 def test_make_repo_delete_command_includes_dry_run():
@@ -113,9 +117,10 @@ def test_make_repo_delete_command_includes_dry_run():
         global_arguments=flexmock(dry_run=True),
         local_path='borg',
         remote_path=None,
+        output_file=None,
     )
 
-    assert command == ('borg', 'repo-delete', '--dry-run', 'repo')
+    assert command == ('borg', 'repo-delete', '--dry-run', '--log-json', 'repo')
 
 
 def test_make_repo_delete_command_includes_remote_path():
@@ -138,9 +143,10 @@ def test_make_repo_delete_command_includes_remote_path():
         global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path='borg1',
+        output_file=None,
     )
 
-    assert command == ('borg', 'repo-delete', '--remote-path', 'borg1', 'repo')
+    assert command == ('borg', 'repo-delete', '--remote-path', 'borg1', '--log-json', 'repo')
 
 
 def test_make_repo_delete_command_includes_umask():
@@ -161,34 +167,10 @@ def test_make_repo_delete_command_includes_umask():
         global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
+        output_file=None,
     )
 
-    assert command == ('borg', 'repo-delete', '--umask', '077', 'repo')
-
-
-def test_make_repo_delete_command_includes_log_json():
-    flexmock(module.borgmatic.borg.feature).should_receive('available').and_return(True)
-    flexmock(module.borgmatic.borg.flags).should_receive('make_flags').and_return(())
-    flexmock(module.borgmatic.borg.flags).should_receive('make_flags').with_args(
-        'log-json',
-        True,
-    ).and_return(('--log-json',))
-    flexmock(module.borgmatic.borg.flags).should_receive('make_flags_from_arguments').and_return(())
-    flexmock(module.borgmatic.borg.flags).should_receive('make_repository_flags').and_return(
-        ('repo',),
-    )
-
-    command = module.make_repo_delete_command(
-        repository={'path': 'repo'},
-        config={'log_json': True},
-        local_borg_version='1.2.3',
-        repo_delete_arguments=flexmock(list_details=False, force=0),
-        global_arguments=flexmock(dry_run=False),
-        local_path='borg',
-        remote_path=None,
-    )
-
-    assert command == ('borg', 'repo-delete', '--log-json', 'repo')
+    assert command == ('borg', 'repo-delete', '--umask', '077', '--log-json', 'repo')
 
 
 def test_make_repo_delete_command_includes_lock_wait():
@@ -211,12 +193,35 @@ def test_make_repo_delete_command_includes_lock_wait():
         global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
+        output_file=None,
     )
 
-    assert command == ('borg', 'repo-delete', '--lock-wait', '5', 'repo')
+    assert command == ('borg', 'repo-delete', '--log-json', '--lock-wait', '5', 'repo')
 
 
-def test_make_repo_delete_command_includes_extra_borg_options():
+def test_make_repo_delete_command_without_feature_available_includes_delete_extra_borg_options():
+    flexmock(module.borgmatic.borg.feature).should_receive('available').and_return(False)
+    flexmock(module.borgmatic.borg.flags).should_receive('make_flags').and_return(())
+    flexmock(module.borgmatic.borg.flags).should_receive('make_flags_from_arguments').and_return(())
+    flexmock(module.borgmatic.borg.flags).should_receive('make_repository_flags').and_return(
+        ('repo',),
+    )
+
+    command = module.make_repo_delete_command(
+        repository={'path': 'repo'},
+        config={'extra_borg_options': {'delete': '--extra "value with space"'}},
+        local_borg_version='1.2.3',
+        repo_delete_arguments=flexmock(list_details=False, force=0),
+        global_arguments=flexmock(dry_run=False),
+        local_path='borg',
+        remote_path=None,
+        output_file=None,
+    )
+
+    assert command == ('borg', 'delete', '--log-json', '--extra', 'value with space', 'repo')
+
+
+def test_make_repo_delete_command_with_feature_available_includes_delete_extra_borg_options():
     flexmock(module.borgmatic.borg.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags_from_arguments').and_return(())
@@ -232,9 +237,10 @@ def test_make_repo_delete_command_includes_extra_borg_options():
         global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
+        output_file=None,
     )
 
-    assert command == ('borg', 'repo-delete', '--extra', 'value with space', 'repo')
+    assert command == ('borg', 'repo-delete', '--log-json', '--extra', 'value with space', 'repo')
 
 
 def test_make_repo_delete_command_includes_list():
@@ -257,9 +263,10 @@ def test_make_repo_delete_command_includes_list():
         global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
+        output_file=None,
     )
 
-    assert command == ('borg', 'repo-delete', '--list', 'repo')
+    assert command == ('borg', 'repo-delete', '--log-json', '--list', 'repo')
 
 
 def test_make_repo_delete_command_includes_force():
@@ -278,9 +285,10 @@ def test_make_repo_delete_command_includes_force():
         global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
+        output_file=None,
     )
 
-    assert command == ('borg', 'repo-delete', '--force', 'repo')
+    assert command == ('borg', 'repo-delete', '--log-json', '--force', 'repo')
 
 
 def test_make_repo_delete_command_includes_force_twice():
@@ -299,13 +307,37 @@ def test_make_repo_delete_command_includes_force_twice():
         global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
+        output_file=None,
     )
 
-    assert command == ('borg', 'repo-delete', '--force', '--force', 'repo')
+    assert command == ('borg', 'repo-delete', '--log-json', '--force', '--force', 'repo')
+
+
+def test_make_repo_delete_command_with_output_file_omits_log_json():
+    flexmock(module.borgmatic.borg.feature).should_receive('available').and_return(True)
+    flexmock(module.borgmatic.borg.flags).should_receive('make_flags').and_return(())
+    flexmock(module.borgmatic.borg.flags).should_receive('make_flags_from_arguments').and_return(())
+    flexmock(module.borgmatic.borg.flags).should_receive('make_repository_flags').and_return(
+        ('repo',),
+    )
+
+    command = module.make_repo_delete_command(
+        repository={'path': 'repo'},
+        config={},
+        local_borg_version='1.2.3',
+        repo_delete_arguments=flexmock(list_details=False, force=0),
+        global_arguments=flexmock(dry_run=False),
+        local_path='borg',
+        remote_path=None,
+        output_file=flexmock(),
+    )
+
+    assert command == ('borg', 'repo-delete', 'repo')
 
 
 def test_delete_repository_with_defaults_does_not_capture_output():
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
+    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     command = flexmock()
     flexmock(module).should_receive('make_repo_delete_command').and_return(command)
     flexmock(module.borgmatic.borg.environment).should_receive('make_environment').and_return(
@@ -335,6 +367,7 @@ def test_delete_repository_with_defaults_does_not_capture_output():
 
 def test_delete_repository_with_force_captures_output():
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
+    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     command = flexmock()
     flexmock(module).should_receive('make_repo_delete_command').and_return(command)
     flexmock(module.borgmatic.borg.environment).should_receive('make_environment').and_return(
@@ -364,6 +397,7 @@ def test_delete_repository_with_force_captures_output():
 
 def test_delete_repository_with_cache_only_captures_output():
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
+    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     command = flexmock()
     flexmock(module).should_receive('make_repo_delete_command').and_return(command)
     flexmock(module.borgmatic.borg.environment).should_receive('make_environment').and_return(
@@ -393,6 +427,7 @@ def test_delete_repository_with_cache_only_captures_output():
 
 def test_delete_repository_calls_borg_with_working_directory():
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
+    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     command = flexmock()
     flexmock(module).should_receive('make_repo_delete_command').and_return(command)
     flexmock(module.borgmatic.borg.environment).should_receive('make_environment').and_return(
