@@ -81,7 +81,7 @@ def test_database_names_to_dump_queries_mysql_for_database_names():
         ),
         environment=environment,
         working_directory=None,
-    ).and_return('foo\nbar\nmysql\n').once()
+    ).and_yield('foo', 'bar', 'mysql').once()
 
     names = module.database_names_to_dump(
         {'name': 'all'},
@@ -123,7 +123,7 @@ def test_database_names_to_dump_with_database_name_all_and_skip_names_filters_ou
         ),
         environment=environment,
         working_directory=None,
-    ).and_return('foo\nbar\nbaz\nmysql\n').once()
+    ).and_yield('foo', 'bar', 'baz', 'mysql').once()
 
     names = module.database_names_to_dump(
         {'name': 'all', 'skip_names': ('foo', 'bar')},
@@ -163,7 +163,7 @@ def test_database_names_to_dump_runs_mysql_with_socket_path():
         ),
         environment=environment,
         working_directory=None,
-    ).and_return('foo\nbar\nmysql\n').once()
+    ).and_yield('foo', 'bar', 'mysql').once()
 
     names = module.database_names_to_dump(
         {'name': 'all', 'socket_path': '/socket'},
@@ -202,7 +202,7 @@ def test_database_names_to_dump_with_environment_password_transport_skips_defaul
         ),
         environment=environment,
         working_directory=None,
-    ).and_return('foo\nbar\nmysql\n').once()
+    ).and_yield('foo', 'bar', 'mysql').once()
 
     names = module.database_names_to_dump(
         {'name': 'all', 'password_transport': 'environment'},
@@ -241,7 +241,7 @@ def test_database_names_to_dump_runs_mysql_with_tls():
         ),
         environment=environment,
         working_directory=None,
-    ).and_return('foo\nbar\nmysql\n').once()
+    ).and_yield('foo', 'bar', 'mysql').once()
 
     names = module.database_names_to_dump(
         {'name': 'all', 'tls': True},
@@ -280,7 +280,7 @@ def test_database_names_to_dump_runs_mysql_without_tls():
         ),
         environment=environment,
         working_directory=None,
-    ).and_return('foo\nbar\nmysql\n').once()
+    ).and_yield('foo', 'bar', 'mysql').once()
 
     names = module.database_names_to_dump(
         {'name': 'all', 'tls': False},
@@ -653,7 +653,7 @@ def test_database_names_to_dump_runs_mysql_with_list_options():
         ),
         environment=None,
         working_directory=None,
-    ).and_return('foo\nbar').once()
+    ).and_yield('foo', 'bar').once()
 
     assert module.database_names_to_dump(database, {}, 'root', 'trustsome1', None, '') == (
         'foo',
@@ -687,7 +687,7 @@ def test_database_names_to_dump_runs_non_default_mysql_with_list_options():
             'show schemas',
         ),
         working_directory=None,
-    ).and_return('foo\nbar').once()
+    ).and_yield('foo', 'bar').once()
 
     assert module.database_names_to_dump(database, {}, 'root', 'trustsome1', None, '') == (
         'foo',
@@ -1235,7 +1235,8 @@ def test_restore_data_source_dump_runs_mysql_to_restore():
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
         working_directory=None,
-    ).once()
+        borg_local_path='borg',
+    ).and_yield().once()
 
     module.restore_data_source_dump(
         hook_config,
@@ -1276,7 +1277,8 @@ def test_restore_data_source_dump_runs_mysql_with_options():
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
         working_directory=None,
-    ).once()
+        borg_local_path='borg',
+    ).and_yield().once()
 
     module.restore_data_source_dump(
         hook_config,
@@ -1317,7 +1319,8 @@ def test_restore_data_source_dump_runs_non_default_mysql_with_options():
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
         working_directory=None,
-    ).once()
+        borg_local_path='borg',
+    ).and_yield().once()
 
     module.restore_data_source_dump(
         hook_config,
@@ -1369,7 +1372,8 @@ def test_restore_data_source_dump_runs_mysql_with_hostname_and_port():
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
         working_directory=None,
-    ).once()
+        borg_local_path='borg',
+    ).and_yield().once()
 
     module.restore_data_source_dump(
         hook_config,
@@ -1421,7 +1425,8 @@ def test_restore_data_source_dump_runs_mysql_with_socket_path():
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
         working_directory=None,
-    ).once()
+        borg_local_path='borg',
+    ).and_yield().once()
 
     module.restore_data_source_dump(
         hook_config,
@@ -1468,7 +1473,8 @@ def test_restore_data_source_dump_runs_mysql_with_tls():
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
         working_directory=None,
-    ).once()
+        borg_local_path='borg',
+    ).and_yield().once()
 
     module.restore_data_source_dump(
         hook_config,
@@ -1515,7 +1521,8 @@ def test_restore_data_source_dump_runs_mysql_without_tls():
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
         working_directory=None,
-    ).once()
+        borg_local_path='borg',
+    ).and_yield().once()
 
     module.restore_data_source_dump(
         hook_config,
@@ -1558,7 +1565,8 @@ def test_restore_data_source_dump_runs_mysql_with_username_and_password():
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
         working_directory=None,
-    ).once()
+        borg_local_path='borg',
+    ).and_yield().once()
 
     module.restore_data_source_dump(
         hook_config,
@@ -1610,7 +1618,8 @@ def test_restore_data_source_with_environment_password_transport_skips_defaults_
         input_file=extract_process.stdout,
         environment={'USER': 'root', 'MYSQL_PWD': 'trustsome1'},
         working_directory=None,
-    ).once()
+        borg_local_path='borg',
+    ).and_yield().once()
 
     module.restore_data_source_dump(
         hook_config,
@@ -1677,7 +1686,8 @@ def test_restore_data_source_dump_with_connection_params_uses_connection_params_
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
         working_directory=None,
-    ).once()
+        borg_local_path='borg',
+    ).and_yield().once()
 
     module.restore_data_source_dump(
         hook_config,
@@ -1749,7 +1759,8 @@ def test_restore_data_source_dump_without_connection_params_uses_restore_params_
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
         working_directory=None,
-    ).once()
+        borg_local_path='borg',
+    ).and_yield().once()
 
     module.restore_data_source_dump(
         hook_config,
