@@ -40,7 +40,22 @@ from borgmatic import execute as module
         (['borg'], 2, 'borg', [{'code': 99, 'treat_as': 'warning'}], module.Exit_status.ERROR),
         (['borg'], 2, 'borg', [{'code': 2, 'treat_as': 'warning'}], module.Exit_status.WARNING),
         (['borg'], 100, 'borg', [{'code': 1, 'treat_as': 'error'}], module.Exit_status.WARNING),
+        (['borg'], 100, 'borg', [], module.Exit_status.WARNING),
         (['borg'], 100, 'borg', [{'code': 100, 'treat_as': 'error'}], module.Exit_status.ERROR),
+        (['borg'], 101, 'borg', [], module.Exit_status.ERROR),
+        (['borg'], 101, 'borg', [{'code': 101, 'treat_as': 'warning'}], module.Exit_status.WARNING),
+        (['borg'], 102, 'borg', [], module.Exit_status.ERROR),
+        (['borg'], 102, 'borg', [{'code': 102, 'treat_as': 'warning'}], module.Exit_status.WARNING),
+        (['borg'], 103, 'borg', [], module.Exit_status.WARNING),
+        (['borg'], 103, 'borg', [{'code': 103, 'treat_as': 'error'}], module.Exit_status.ERROR),
+        (['borg'], 104, 'borg', [], module.Exit_status.ERROR),
+        (['borg'], 104, 'borg', [{'code': 104, 'treat_as': 'warning'}], module.Exit_status.WARNING),
+        (['borg'], 105, 'borg', [], module.Exit_status.ERROR),
+        (['borg'], 105, 'borg', [{'code': 105, 'treat_as': 'warning'}], module.Exit_status.WARNING),
+        (['borg'], 106, 'borg', [], module.Exit_status.ERROR),
+        (['borg'], 106, 'borg', [{'code': 106, 'treat_as': 'warning'}], module.Exit_status.WARNING),
+        (['borg'], 107, 'borg', [], module.Exit_status.ERROR),
+        (['borg'], 107, 'borg', [{'code': 107, 'treat_as': 'warning'}], module.Exit_status.WARNING),
     ),
 )
 def test_interpret_exit_code_respects_exit_code_and_borg_local_path(
@@ -68,68 +83,185 @@ def test_command_for_process_passes_through_string_command():
     assert module.command_for_process(process) == 'foo bar baz'
 
 
-def test_output_buffer_for_process_returns_stderr_when_stdout_excluded():
+def test_output_buffers_for_process_returns_stdout_and_stderr_by_default():
     stdout = flexmock()
     stderr = flexmock()
     process = flexmock(stdout=stdout, stderr=stderr)
 
-    assert module.output_buffer_for_process(process, exclude_stdouts=[flexmock(), stdout]) == stderr
-
-
-def test_output_buffer_for_process_returns_stdout_when_not_excluded():
-    stdout = flexmock()
-    process = flexmock(stdout=stdout)
-
-    assert (
-        module.output_buffer_for_process(process, exclude_stdouts=[flexmock(), flexmock()])
-        == stdout
+    assert module.output_buffers_for_process(process, exclude_stdouts=[flexmock(), flexmock()]) == (
+        stdout,
+        stderr,
     )
 
 
-def test_append_last_lines_under_max_line_count_appends():
-    last_lines = ['last']
-    flexmock(module.logger).should_receive('log').once()
+def test_output_buffers_for_process_returns_stderr_only_when_stdout_excluded():
+    stdout = flexmock()
+    stderr = flexmock()
+    process = flexmock(stdout=stdout, stderr=stderr)
 
-    module.append_last_lines(
-        last_lines,
-        captured_output=flexmock(),
-        line='line',
-        output_log_level=flexmock(),
+    assert module.output_buffers_for_process(process, exclude_stdouts=[flexmock(), stdout]) == (
+        stderr,
+    )
+
+
+def test_borg_json_log_line_to_record_parses_log_message_line():
+    line = '{"type": "log_message", "levelname": "INFO", "time": 12345, "message": "All done", "name": "borg.something"}'
+
+    record = module.borg_json_log_line_to_record(line, module.logging.INFO)
+
+    assert record.levelno == module.logging.INFO
+    assert record.created == 12345
+    assert record.msg == 'All done'
+    assert record.levelname == 'INFO'
+    assert record.name == 'borg.something'
+
+
+def test_borg_json_log_line_to_record_parses_file_status_line():
+    flexmock(module.time).should_receive('time').and_return(12345)
+    line = '{"type": "file_status", "status": "-", "path": "/foo/bar"}'
+
+    record = module.borg_json_log_line_to_record(line, module.logging.INFO)
+
+    assert record.levelno == module.logging.INFO
+    assert record.created == 12345
+    assert record.msg == '- /foo/bar'
+    assert record.levelname == 'INFO'
+    assert record.name == 'borg.file_status'
+
+
+def test_borg_json_log_line_to_record_handles_invalid_json():
+    line = '{invalid'
+
+    assert module.borg_json_log_line_to_record(line, module.logging.INFO) is None
+
+
+def test_borg_json_log_line_to_record_handles_non_dict_json():
+    line = '[]'
+
+    assert module.borg_json_log_line_to_record(line, module.logging.INFO) is None
+
+
+def test_borg_json_log_line_to_record_handles_json_dict_without_type():
+    line = '{"status": "-", "path": "/foo/bar"}'
+
+    assert module.borg_json_log_line_to_record(line, module.logging.INFO) is None
+
+
+def test_log_line_to_record_makes_log_record():
+    line = 'All done'
+
+    record = module.log_line_to_record(line, module.logging.INFO)
+
+    assert record.msg == line
+    assert record.levelno == module.logging.INFO
+    assert record.levelname == 'INFO'
+
+
+def test_parse_log_line_with_borg_command_parses_borg_log_line():
+    record = flexmock()
+    flexmock(module).should_receive('borg_json_log_line_to_record').and_return(record).once()
+    flexmock(module).should_receive('log_line_to_record').never()
+
+    assert (
+        module.parse_log_line(
+            'All done',
+            module.logging.INFO,
+            elevate_stderr=False,
+            borg_local_path='borg',
+            command=['borg', 'do-stuff'],
+        )
+        == record
+    )
+
+
+def test_parse_log_line_without_borg_command_parses_plain_log_line():
+    record = flexmock()
+    flexmock(module).should_receive('borg_json_log_line_to_record').never()
+    flexmock(module).should_receive('log_line_to_record').and_return(record).once()
+
+    assert (
+        module.parse_log_line(
+            'All done',
+            module.logging.INFO,
+            elevate_stderr=False,
+            borg_local_path='borg',
+            command=['totally-not-borg', 'do-stuff'],
+        )
+        == record
+    )
+
+
+def test_parse_log_line_with_elevate_stderr_makes_error_record():
+    record = flexmock()
+    flexmock(module).should_receive('borg_json_log_line_to_record').never()
+    flexmock(module).should_receive('log_line_to_record').with_args(
+        'All done', module.logging.ERROR
+    ).and_return(record).once()
+
+    assert (
+        module.parse_log_line(
+            'All done',
+            module.logging.INFO,
+            elevate_stderr=True,
+            borg_local_path='borg',
+            command=['totally-not-borg', 'do-stuff'],
+        )
+        == record
+    )
+
+
+def test_parse_log_line_with_elevate_stderr_and_warning_prefix_makes_warning_record():
+    record = flexmock()
+    flexmock(module).should_receive('borg_json_log_line_to_record').never()
+    flexmock(module).should_receive('log_line_to_record').with_args(
+        'warning: All done', module.logging.WARNING
+    ).and_return(record).once()
+
+    assert (
+        module.parse_log_line(
+            'warning: All done',
+            module.logging.INFO,
+            elevate_stderr=True,
+            borg_local_path='borg',
+            command=['totally-not-borg', 'do-stuff'],
+        )
+        == record
+    )
+
+
+def test_handle_log_record_under_max_line_count_appends():
+    last_lines = ['last']
+    flexmock(module.logger).should_receive('handle').once()
+    log_record = flexmock(levelno=module.logging.INFO, getMessage=lambda: 'line')
+
+    assert (
+        module.handle_log_record(
+            log_record,
+            last_lines,
+        )
+        == log_record
     )
 
     assert last_lines == ['last', 'line']
 
 
-def test_append_last_lines_over_max_line_count_trims_and_appends():
+def test_handle_log_record_over_max_line_count_trims_and_appends():
     original_last_lines = [str(number) for number in range(module.ERROR_OUTPUT_MAX_LINE_COUNT)]
     last_lines = list(original_last_lines)
-    flexmock(module.logger).should_receive('log').once()
+    flexmock(module.logger).should_receive('handle').once()
+    log_record = flexmock(levelno=module.logging.INFO, getMessage=lambda: 'line')
 
-    module.append_last_lines(
-        last_lines,
-        captured_output=flexmock(),
-        line='line',
-        output_log_level=flexmock(),
+    assert (
+        module.handle_log_record(
+            log_record,
+            last_lines,
+        )
+        == log_record
     )
 
     assert last_lines == [*original_last_lines[1:], 'line']
 
 
-def test_append_last_lines_with_output_log_level_none_appends_captured_output():
-    last_lines = ['last']
-    captured_output = ['captured']
-    flexmock(module.logger).should_receive('log').never()
-
-    module.append_last_lines(
-        last_lines,
-        captured_output=captured_output,
-        line='line',
-        output_log_level=None,
-    )
-
-    assert captured_output == ['captured', 'line']
-
-
 def test_mask_command_secrets_masks_password_flag_value():
     assert module.mask_command_secrets(('cooldb', '--username', 'bob', '--password', 'pass')) == (
         'cooldb',
@@ -204,14 +336,14 @@ def test_execute_command_calls_full_command():
         full_command,
         stdin=None,
         stdout=module.subprocess.PIPE,
-        stderr=module.subprocess.STDOUT,
+        stderr=module.subprocess.PIPE,
         shell=False,
         env=None,
         cwd=None,
         close_fds=False,
     ).and_return(flexmock(stdout=None)).once()
     flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
-    flexmock(module).should_receive('log_outputs')
+    flexmock(module).should_receive('log_outputs').and_yield()
 
     output = module.execute_command(full_command)
 
@@ -233,7 +365,7 @@ def test_execute_command_calls_full_command_with_output_file():
         close_fds=False,
     ).and_return(flexmock(stderr=None)).once()
     flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
-    flexmock(module).should_receive('log_outputs')
+    flexmock(module).should_receive('log_outputs').and_yield()
 
     output = module.execute_command(full_command, output_file=output_file)
 
@@ -255,7 +387,7 @@ def test_execute_command_calls_full_command_without_capturing_output():
     ).and_return(flexmock(wait=lambda: 0)).once()
     flexmock(module).should_receive('interpret_exit_code').and_return(module.Exit_status.SUCCESS)
     flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
-    flexmock(module).should_receive('log_outputs')
+    flexmock(module).should_receive('log_outputs').and_yield()
 
     output = module.execute_command(full_command, output_file=module.DO_NOT_CAPTURE)
 
@@ -270,14 +402,14 @@ def test_execute_command_calls_full_command_with_input_file():
         full_command,
         stdin=input_file,
         stdout=module.subprocess.PIPE,
-        stderr=module.subprocess.STDOUT,
+        stderr=module.subprocess.PIPE,
         shell=False,
         env=None,
         cwd=None,
         close_fds=False,
     ).and_return(flexmock(stdout=None)).once()
     flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
-    flexmock(module).should_receive('log_outputs')
+    flexmock(module).should_receive('log_outputs').and_yield()
 
     output = module.execute_command(full_command, input_file=input_file)
 
@@ -291,14 +423,14 @@ def test_execute_command_calls_full_command_with_shell():
         ' '.join(full_command),
         stdin=None,
         stdout=module.subprocess.PIPE,
-        stderr=module.subprocess.STDOUT,
+        stderr=module.subprocess.PIPE,
         shell=True,
         env=None,
         cwd=None,
         close_fds=False,
     ).and_return(flexmock(stdout=None)).once()
     flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
-    flexmock(module).should_receive('log_outputs')
+    flexmock(module).should_receive('log_outputs').and_yield()
 
     output = module.execute_command(full_command, shell=True)
 
@@ -312,14 +444,14 @@ def test_execute_command_calls_full_command_with_environment():
         full_command,
         stdin=None,
         stdout=module.subprocess.PIPE,
-        stderr=module.subprocess.STDOUT,
+        stderr=module.subprocess.PIPE,
         shell=False,
         env={'a': 'b'},
         cwd=None,
         close_fds=False,
     ).and_return(flexmock(stdout=None)).once()
     flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
-    flexmock(module).should_receive('log_outputs')
+    flexmock(module).should_receive('log_outputs').and_yield()
 
     output = module.execute_command(full_command, environment={'a': 'b'})
 
@@ -333,14 +465,14 @@ def test_execute_command_calls_full_command_with_working_directory():
         full_command,
         stdin=None,
         stdout=module.subprocess.PIPE,
-        stderr=module.subprocess.STDOUT,
+        stderr=module.subprocess.PIPE,
         shell=False,
         env=None,
         cwd='/working',
         close_fds=False,
     ).and_return(flexmock(stdout=None)).once()
     flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
-    flexmock(module).should_receive('log_outputs')
+    flexmock(module).should_receive('log_outputs').and_yield()
 
     output = module.execute_command(full_command, working_directory='/working')
 
@@ -355,65 +487,72 @@ def test_execute_command_without_run_to_completion_returns_process():
         full_command,
         stdin=None,
         stdout=module.subprocess.PIPE,
-        stderr=module.subprocess.STDOUT,
+        stderr=module.subprocess.PIPE,
         shell=False,
         env=None,
         cwd=None,
         close_fds=False,
     ).and_return(process).once()
     flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
-    flexmock(module).should_receive('log_outputs')
+    flexmock(module).should_receive('log_outputs').and_yield()
 
     assert module.execute_command(full_command, run_to_completion=False) == process
 
 
 def test_execute_command_and_capture_output_returns_stdout():
     full_command = ['foo', 'bar']
-    expected_output = '[]'
     flexmock(module).should_receive('log_command')
-    flexmock(module.subprocess).should_receive('check_output').with_args(
+    process = flexmock()
+    flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command,
         stdin=None,
-        stderr=None,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
         shell=False,
         env=None,
         cwd=None,
         close_fds=False,
-    ).and_return(flexmock(decode=lambda: expected_output)).once()
+    ).and_return(process).once()
+    flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
+    flexmock(module).should_receive('log_outputs').and_yield('out')
 
-    output = module.execute_command_and_capture_output(full_command)
+    output_lines = tuple(module.execute_command_and_capture_output(full_command))
 
-    assert output == expected_output
+    assert output_lines == ('out',)
 
 
 def test_execute_command_and_capture_output_with_capture_stderr_returns_stderr():
     full_command = ['foo', 'bar']
-    expected_output = '[]'
-    flexmock(module).should_receive('log_command')
-    flexmock(module.subprocess).should_receive('check_output').with_args(
+    process = flexmock()
+    flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command,
         stdin=None,
-        stderr=module.subprocess.STDOUT,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
         shell=False,
         env=None,
         cwd=None,
         close_fds=False,
-    ).and_return(flexmock(decode=lambda: expected_output)).once()
+    ).and_return(process).once()
+    flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
+    flexmock(module).should_receive('log_outputs').and_yield('out')
 
-    output = module.execute_command_and_capture_output(full_command, capture_stderr=True)
+    output_lines = tuple(
+        module.execute_command_and_capture_output(full_command, capture_stderr=True)
+    )
 
-    assert output == expected_output
+    assert output_lines == ('out',)
 
 
 def test_execute_command_and_capture_output_returns_output_when_process_error_is_not_considered_an_error():
     full_command = ['foo', 'bar']
-    expected_output = '[]'
     err_output = b'[]'
     flexmock(module).should_receive('log_command')
-    flexmock(module.subprocess).should_receive('check_output').with_args(
+    flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command,
         stdin=None,
-        stderr=None,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
         shell=False,
         env=None,
         cwd=None,
@@ -423,95 +562,108 @@ def test_execute_command_and_capture_output_returns_output_when_process_error_is
         module.Exit_status.SUCCESS,
     ).once()
 
-    output = module.execute_command_and_capture_output(full_command)
+    output_lines = tuple(module.execute_command_and_capture_output(full_command))
 
-    assert output == expected_output
+    assert output_lines == ('[]',)
 
 
 def test_execute_command_and_capture_output_raises_when_command_errors():
     full_command = ['foo', 'bar']
-    expected_output = '[]'
     flexmock(module).should_receive('log_command')
-    flexmock(module.subprocess).should_receive('check_output').with_args(
+    flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command,
         stdin=None,
-        stderr=None,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
         shell=False,
         env=None,
         cwd=None,
         close_fds=False,
-    ).and_raise(subprocess.CalledProcessError(2, full_command, expected_output)).once()
+    ).and_raise(subprocess.CalledProcessError(2, full_command, 'error')).once()
     flexmock(module).should_receive('interpret_exit_code').and_return(
         module.Exit_status.ERROR,
     ).once()
 
     with pytest.raises(subprocess.CalledProcessError):
-        module.execute_command_and_capture_output(full_command)
+        tuple(module.execute_command_and_capture_output(full_command))
 
 
-def test_execute_command_and_capture_output_returns_output_with_shell():
+def test_execute_command_and_capture_output_with_shell_returns_output():
     full_command = ['foo', 'bar']
-    expected_output = '[]'
     flexmock(module).should_receive('log_command')
-    flexmock(module.subprocess).should_receive('check_output').with_args(
+    process = flexmock()
+    flexmock(module.subprocess).should_receive('Popen').with_args(
         'foo bar',
         stdin=None,
-        stderr=None,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
         shell=True,
         env=None,
         cwd=None,
         close_fds=False,
-    ).and_return(flexmock(decode=lambda: expected_output)).once()
+    ).and_return(process).once()
+    flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
+    flexmock(module).should_receive('log_outputs').and_yield('out')
 
-    output = module.execute_command_and_capture_output(full_command, shell=True)
+    output_lines = tuple(module.execute_command_and_capture_output(full_command, shell=True))
 
-    assert output == expected_output
+    assert output_lines == ('out',)
 
 
-def test_execute_command_and_capture_output_returns_output_with_environment():
+def test_execute_command_and_capture_output_with_enviroment_returns_output():
     full_command = ['foo', 'bar']
-    expected_output = '[]'
     flexmock(module).should_receive('log_command')
-    flexmock(module.subprocess).should_receive('check_output').with_args(
+    process = flexmock()
+    flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command,
         stdin=None,
-        stderr=None,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
         shell=False,
         env={'a': 'b'},
         cwd=None,
         close_fds=False,
-    ).and_return(flexmock(decode=lambda: expected_output)).once()
+    ).and_return(process).once()
+    flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
+    flexmock(module).should_receive('log_outputs').and_yield('out')
 
-    output = module.execute_command_and_capture_output(
-        full_command,
-        shell=False,
-        environment={'a': 'b'},
+    output_lines = tuple(
+        module.execute_command_and_capture_output(
+            full_command,
+            shell=False,
+            environment={'a': 'b'},
+        )
     )
 
-    assert output == expected_output
+    assert output_lines == ('out',)
 
 
 def test_execute_command_and_capture_output_returns_output_with_working_directory():
     full_command = ['foo', 'bar']
-    expected_output = '[]'
     flexmock(module).should_receive('log_command')
-    flexmock(module.subprocess).should_receive('check_output').with_args(
+    process = flexmock()
+    flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command,
         stdin=None,
-        stderr=None,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
         shell=False,
         env=None,
         cwd='/working',
         close_fds=False,
-    ).and_return(flexmock(decode=lambda: expected_output)).once()
+    ).and_return(process).once()
+    flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
+    flexmock(module).should_receive('log_outputs').and_yield('out')
 
-    output = module.execute_command_and_capture_output(
-        full_command,
-        shell=False,
-        working_directory='/working',
+    output_lines = tuple(
+        module.execute_command_and_capture_output(
+            full_command,
+            shell=False,
+            working_directory='/working',
+        )
     )
 
-    assert output == expected_output
+    assert output_lines == ('out',)
 
 
 def test_execute_command_with_processes_calls_full_command():
@@ -522,18 +674,18 @@ def test_execute_command_with_processes_calls_full_command():
         full_command,
         stdin=None,
         stdout=module.subprocess.PIPE,
-        stderr=module.subprocess.STDOUT,
+        stderr=module.subprocess.PIPE,
         shell=False,
         env=None,
         cwd=None,
         close_fds=False,
     ).and_return(flexmock(stdout=None)).once()
     flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
-    flexmock(module).should_receive('log_outputs')
+    flexmock(module).should_receive('log_outputs').and_yield()
 
-    output = module.execute_command_with_processes(full_command, processes)
+    output_lines = tuple(module.execute_command_with_processes(full_command, processes))
 
-    assert output is None
+    assert output_lines == ()
 
 
 def test_execute_command_with_processes_returns_output_with_output_log_level_none():
@@ -545,18 +697,20 @@ def test_execute_command_with_processes_returns_output_with_output_log_level_non
         full_command,
         stdin=None,
         stdout=module.subprocess.PIPE,
-        stderr=module.subprocess.STDOUT,
+        stderr=module.subprocess.PIPE,
         shell=False,
         env=None,
         cwd=None,
         close_fds=False,
     ).and_return(process).once()
     flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
-    flexmock(module).should_receive('log_outputs').and_return({process: 'out'})
+    flexmock(module).should_receive('log_outputs').and_yield('out')
 
-    output = module.execute_command_with_processes(full_command, processes, output_log_level=None)
+    output_lines = tuple(
+        module.execute_command_with_processes(full_command, processes, output_log_level=None)
+    )
 
-    assert output == 'out'
+    assert output_lines == ('out',)
 
 
 def test_execute_command_with_processes_calls_full_command_with_output_file():
@@ -575,11 +729,13 @@ def test_execute_command_with_processes_calls_full_command_with_output_file():
         close_fds=False,
     ).and_return(flexmock(stderr=None)).once()
     flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
-    flexmock(module).should_receive('log_outputs')
+    flexmock(module).should_receive('log_outputs').and_yield()
 
-    output = module.execute_command_with_processes(full_command, processes, output_file=output_file)
+    output_lines = tuple(
+        module.execute_command_with_processes(full_command, processes, output_file=output_file)
+    )
 
-    assert output is None
+    assert output_lines == ()
 
 
 def test_execute_command_with_processes_calls_full_command_without_capturing_output():
@@ -598,15 +754,17 @@ def test_execute_command_with_processes_calls_full_command_without_capturing_out
     ).and_return(flexmock(wait=lambda: 0)).once()
     flexmock(module).should_receive('interpret_exit_code').and_return(module.Exit_status.SUCCESS)
     flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
-    flexmock(module).should_receive('log_outputs')
+    flexmock(module).should_receive('log_outputs').and_yield()
 
-    output = module.execute_command_with_processes(
-        full_command,
-        processes,
-        output_file=module.DO_NOT_CAPTURE,
+    output_lines = tuple(
+        module.execute_command_with_processes(
+            full_command,
+            processes,
+            output_file=module.DO_NOT_CAPTURE,
+        )
     )
 
-    assert output is None
+    assert output_lines == ()
 
 
 def test_execute_command_with_processes_calls_full_command_with_input_file():
@@ -618,18 +776,20 @@ def test_execute_command_with_processes_calls_full_command_with_input_file():
         full_command,
         stdin=input_file,
         stdout=module.subprocess.PIPE,
-        stderr=module.subprocess.STDOUT,
+        stderr=module.subprocess.PIPE,
         shell=False,
         env=None,
         cwd=None,
         close_fds=False,
     ).and_return(flexmock(stdout=None)).once()
     flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
-    flexmock(module).should_receive('log_outputs')
+    flexmock(module).should_receive('log_outputs').and_yield()
 
-    output = module.execute_command_with_processes(full_command, processes, input_file=input_file)
+    output_lines = tuple(
+        module.execute_command_with_processes(full_command, processes, input_file=input_file)
+    )
 
-    assert output is None
+    assert output_lines == ()
 
 
 def test_execute_command_with_processes_calls_full_command_with_shell():
@@ -640,18 +800,18 @@ def test_execute_command_with_processes_calls_full_command_with_shell():
         ' '.join(full_command),
         stdin=None,
         stdout=module.subprocess.PIPE,
-        stderr=module.subprocess.STDOUT,
+        stderr=module.subprocess.PIPE,
         shell=True,
         env=None,
         cwd=None,
         close_fds=False,
     ).and_return(flexmock(stdout=None)).once()
     flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
-    flexmock(module).should_receive('log_outputs')
+    flexmock(module).should_receive('log_outputs').and_yield()
 
-    output = module.execute_command_with_processes(full_command, processes, shell=True)
+    output_lines = tuple(module.execute_command_with_processes(full_command, processes, shell=True))
 
-    assert output is None
+    assert output_lines == ()
 
 
 def test_execute_command_with_processes_calls_full_command_with_environment():
@@ -662,18 +822,20 @@ def test_execute_command_with_processes_calls_full_command_with_environment():
         full_command,
         stdin=None,
         stdout=module.subprocess.PIPE,
-        stderr=module.subprocess.STDOUT,
+        stderr=module.subprocess.PIPE,
         shell=False,
         env={'a': 'b'},
         cwd=None,
         close_fds=False,
     ).and_return(flexmock(stdout=None)).once()
     flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
-    flexmock(module).should_receive('log_outputs')
+    flexmock(module).should_receive('log_outputs').and_yield()
 
-    output = module.execute_command_with_processes(full_command, processes, environment={'a': 'b'})
+    output_lines = tuple(
+        module.execute_command_with_processes(full_command, processes, environment={'a': 'b'})
+    )
 
-    assert output is None
+    assert output_lines == ()
 
 
 def test_execute_command_with_processes_calls_full_command_with_working_directory():
@@ -684,22 +846,24 @@ def test_execute_command_with_processes_calls_full_command_with_working_director
         full_command,
         stdin=None,
         stdout=module.subprocess.PIPE,
-        stderr=module.subprocess.STDOUT,
+        stderr=module.subprocess.PIPE,
         shell=False,
         env=None,
         cwd='/working',
         close_fds=False,
     ).and_return(flexmock(stdout=None)).once()
     flexmock(module.borgmatic.logger).should_receive('Log_prefix').and_return(flexmock())
-    flexmock(module).should_receive('log_outputs')
+    flexmock(module).should_receive('log_outputs').and_yield()
 
-    output = module.execute_command_with_processes(
-        full_command,
-        processes,
-        working_directory='/working',
+    output_lines = tuple(
+        module.execute_command_with_processes(
+            full_command,
+            processes,
+            working_directory='/working',
+        )
     )
 
-    assert output is None
+    assert output_lines == ()
 
 
 def test_execute_command_with_processes_kills_processes_on_error():
@@ -713,7 +877,7 @@ def test_execute_command_with_processes_kills_processes_on_error():
         full_command,
         stdin=None,
         stdout=module.subprocess.PIPE,
-        stderr=module.subprocess.STDOUT,
+        stderr=module.subprocess.PIPE,
         shell=False,
         env=None,
         cwd=None,
@@ -723,4 +887,4 @@ def test_execute_command_with_processes_kills_processes_on_error():
     flexmock(module).should_receive('log_outputs').never()
 
     with pytest.raises(subprocess.CalledProcessError):
-        module.execute_command_with_processes(full_command, processes)
+        tuple(module.execute_command_with_processes(full_command, processes))
